# NebhutDukes_CalleryPear_Analysis.R
# Created on 2021-08-19
# Last edited on 2023-08-04
# Created by Andrea Nebhut

# **********************************************************************************************************
# DOCUMENT SET-UP ####
# **********************************************************************************************************
# Clear R's memory
rm(list = ls())

## Take a list of packages, install them to the local library, if necessary, and then load them all
packageHandler <- function(packageList = packages) {
  # Install packages if necessary
  installed_packages <- packages %in% rownames(installed.packages())
  if (any(installed_packages == FALSE)) {
    install.packages(packages[!installed_packages])
  }

  # Load packages
  invisible(lapply(packages, library, character.only = TRUE))
}

# list of all packages used
packages <- c(
  "ggplot2", "ggpubr", "ggrepel", "ggtext", "plyr", "scales", "sjstats", "vegan",
  "betapart", "tcltk", "BiodiversityR", "multcompView", "data.table", "tidyr", "grafify"
)

# install packages if necessary, and load them all
packageHandler(packages)

# Set working directory
setwd("C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Data")

# Set output directory based on working directory
outputDir <- paste0(getwd(), "/output/")

# check if directory exists, create if not
newDir <- function(dirPath) {
  if (dir.exists(dirPath)) {
    cat(sprintf("Output directory, %s, already exists\n", dirPath))
  } else {
    cat(sprintf("Output directory not found, creating: %s\n", dirPath))
    dir.create(dirPath)
  }
}

# create output directory if needed
newDir(outputDir)

# Load data
data <- read.csv(file = "P_Calleryana_Cover_Data.csv", header = TRUE)
species_info <- read.csv(file = "P_Calleryana_Species_Information.csv", header = TRUE)

# Set standard error equation
se <- function(x) sd(x) / sqrt(length(x))

# Fix the multicompLetters4 function
# (it otherwise throws an error message when you include a covariate)
# For plot, location, and their interaction
multcompLetters4_fixed <- function(object, comp) {
  formula <- terms(object)
  Terms <- c("Plot", "Location", "Plot:Location")
  data <- model.frame(object)
  fm <- as.character(formula)
  fm <- fm[-1]
  fms <- list()
  for (i in 1:length(Terms)) {
    fms[[i]] <- formula(paste(fm[1], "~", Terms[i]))
  }
  names(fms) <- Terms
  if (is.character(comp) | is.symbol(comp)) {
    comp <- match.fun(comp)
    comp <- comp(object)
  }
  comp <- extract_p(comp)
  ans <- list()
  for (i in 1:length(Terms)) {
    ans[[i]] <- list(formula = fms[[i]], p = comp[[i]])
  }
  names(ans) <- Terms
  lapply(ans, function(x) {
    multcompLetters2(
      x$formula, x$p,
      data
    )
  })
}

# For plot only
multcompLetters4_fixed_2 <- function(object, comp) {
  formula <- terms(object)
  Terms <- c("Plot")
  data <- model.frame(object)
  fm <- as.character(formula)
  fm <- fm[-1]
  fms <- list()
  for (i in 1:length(Terms)) {
    fms[[i]] <- formula(paste(fm[1], "~", Terms[i]))
  }
  names(fms) <- Terms
  if (is.character(comp) | is.symbol(comp)) {
    comp <- match.fun(comp)
    comp <- comp(object)
  }
  comp <- extract_p(comp)
  ans <- list()
  for (i in 1:length(Terms)) {
    ans[[i]] <- list(formula = fms[[i]], p = comp[[i]])
  }
  names(ans) <- Terms
  lapply(ans, function(x) {
    multcompLetters2(
      x$formula, x$p,
      data
    )
  })
}

# Set the color palette
color_palette <- c(
  "PLOC" = "#FDE725",
  "LITU" = "#7AD151",
  "PYCA80" = "#22A384",
  "SP" = "#2A788E"
)

# **********************************************************************************************************
# INITIAL CALCULATIONS AND DATA FORMATTING ####
# **********************************************************************************************************
# Split the community datasheet into separate sheets for just the introduced
# understory species, the native understory species, the woody understory species
# and the native tree species

# Get relevant species names
introduced_species_names <- as.list(species_info[species_info$Origin %in% c("Introduced"), 1])
native_species_names <- as.list(species_info[species_info$Origin %in% c("Native"), 1])
woody_species_names <- as.list(species_info[species_info$Growth_Form_Woody %in% c("Woody"), 1])
tree_species_names <- species_info[species_info$Growth_Form %in% c("Tree"), ]
native_tree_species_names <- (tree_species_names[tree_species_names$Origin %in% c("Native"), 1])

# Remove spaces
introduced_species_names <- gsub(" ", ".", introduced_species_names, fixed = TRUE)
native_species_names <- gsub(" ", ".", native_species_names, fixed = TRUE)
woody_species_names <- gsub(" ", ".", woody_species_names, fixed = TRUE)
native_tree_species_names <- gsub(" ", ".", native_tree_species_names, fixed = TRUE)

# Subset community dataset with species names from above
data_introduced <- data[, c("Plot_ID", "Location", "Plot", "DBH", introduced_species_names)]
data_native <- data[, c("Plot_ID", "Location", "Plot", "DBH", native_species_names)]
data_woody <- data[, c("Plot_ID", "Location", "Plot", "DBH", woody_species_names)]
data_native_trees <- data[, c("Plot_ID", "Location", "Plot", "DBH", native_tree_species_names)]

# Now that we've split the dataset, we can calculate diversity indices for each
# subset of the community

# replace NAs with 0s
data[is.na(data)] <- 0
data_introduced[is.na(data_introduced)] <- 0
data_native[is.na(data_native)] <- 0
data_woody[is.na(data_woody)] <- 0
data_native_trees[is.na(data_native_trees)] <- 0

# Calculate species richness of each subset of each plot
data$species_richness <- specnumber(data[, 5:136])
data_introduced$species_richness <- specnumber(data_introduced[, 5:41])
data_native$species_richness <- specnumber(data_native[, 5:99])
data_woody$species_richness <- specnumber(data_woody[, 5:37])
data_native_trees$species_richness <- specnumber(data_native_trees[, 5:26])

# Calculate total cover of each subset of each plot
data$total_cover <- rowSums(data[, 5:136])
data_introduced$total_cover <- rowSums(data_introduced[, 5:41])
data_native$total_cover <- rowSums(data_native[, 5:99])
data_woody$total_cover <- rowSums(data_woody[, 5:37])
data_native_trees$total_cover <- rowSums(data_native_trees[, 5:26])

# Calculate species diversity (Shannon Index) of each subset of each plot
data$shannon_index <- diversity(data[, 5:136], index = "shannon")
data_introduced$shannon_index <- diversity(data_introduced[, 5:41], index = "shannon")
data_native$shannon_index <- diversity(data_native[, 5:99], index = "shannon")
data_woody$shannon_index <- diversity(data_woody[, 5:37], index = "shannon")
data_native_trees$shannon_index <- diversity(data_native_trees[, 5:26], index = "shannon")

# Calculate species diversity (Simpson Index) of each subset of each plot
data$simpson_index <- diversity(data[, 5:136], index = "simpson")
data_introduced$simpson_index <- diversity(data_introduced[, 5:41], index = "simpson")
data_native$simpson_index <- diversity(data_native[, 5:99], index = "simpson")
data_woody$simpson_index <- diversity(data_woody[, 5:37], index = "simpson")
data_native_trees$simpson_index <- diversity(data_native_trees[, 5:26], index = "simpson")

# Include only selected species (remove MONI and PRSE2)
data_primary_species <- data[data$Plot %in% c("LITU", "PYCA80", "PLOC", "SP"), ]
data_primary_species_introduced <- data_introduced[data_introduced$Plot %in% c("LITU", "PYCA80", "PLOC", "SP"), ]
data_primary_species_native <- data_native[data_native$Plot %in% c("LITU", "PYCA80", "PLOC", "SP"), ]
data_primary_species_woody <- data_woody[data_woody$Plot %in% c("LITU", "PYCA80", "PLOC", "SP"), ]
data_primary_species_native_trees <- data_native_trees[data_native_trees$Plot %in% c("LITU", "PYCA80", "PLOC", "SP"), ]

# Remove SPs for DBH analysis
data_primary_species_no_SP <- data[data$Plot %in% c("LITU", "PYCA80", "PLOC"), ]
data_primary_species_no_SP_introduced <- data_introduced[data_introduced$Plot %in% c("LITU", "PYCA80", "PLOC"), ]
data_primary_species_no_SP_native <- data_native[data_native$Plot %in% c("LITU", "PYCA80", "PLOC"), ]
data_primary_species_no_SP_woody <- data_woody[data_woody$Plot %in% c("LITU", "PYCA80", "PLOC"), ]
data_primary_species_no_SP_native_trees <- data_native_trees[data_native_trees$Plot %in% c("LITU", "PYCA80", "PLOC"), ]

# Calculate mean and se of DBH and convert to cm (1 inch = 2.54 cm)
mean(data_primary_species_no_SP$DBH) * 2.54
se(data_primary_species_no_SP$DBH) * 2.54
range(data_primary_species_no_SP$DBH) * 2.54

DBH_plot_means <- aggregate(DBH ~ Plot, data_primary_species_no_SP, mean) # calculate mean of DBH by plot type
DBH_plot_se <- aggregate(DBH ~ Plot, data_primary_species_no_SP, se) # calculate se of DBH by plot type
DBH_plot_min <- aggregate(DBH ~ Plot, data_primary_species_no_SP, min) # calculate minimum DBH by plot type
DBH_plot_max <- aggregate(DBH ~ Plot, data_primary_species_no_SP, max) # calculate maximum DBH by plot type
DBH_plot_stats <- join_all(list(DBH_plot_means, DBH_plot_se, DBH_plot_min, DBH_plot_max), by = c("Plot")) # combine above datasets
colnames(DBH_plot_stats) <- c("Plot", "Mean_in", "se_in", "Min_in", "Max_in") # rename columns

DBH_plot_stats$Mean_cm <- DBH_plot_stats$Mean_in * 2.54
DBH_plot_stats$se_cm <- DBH_plot_stats$se_in * 2.54
DBH_plot_stats$Min_cm <- DBH_plot_stats$Min_in * 2.54
DBH_plot_stats$Max_cm <- DBH_plot_stats$Max_in * 2.54

data_primary_species_no_SP$DBH_cm <- data_primary_species_no_SP$DBH * 2.54
max(data_primary_species_no_SP$DBH_cm)
min(data_primary_species_no_SP$DBH_cm)

ggplot(data = DBH_plot_stats, aes(x = Plot, y = Mean_cm)) +
  geom_point(
    data = data_primary_species_no_SP,
    aes(x = Plot, y = DBH_cm),
    position = position_jitter(w = 0.2, h = 0),
    alpha = 0.3
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean_cm - se_cm, ymax = Mean_cm + se_cm),
    width = 0.2,
    size = 1,
    position = position_dodge(width = 0.3)
  ) +
  theme_classic(base_size = 18) +
  xlab("Plot Type") +
  ylab("DBH (cm)") +
  scale_x_discrete(labels = c("L. tulipifera", "P. occidentalis", "P. calleryana", "Control")) +
  theme(axis.text.x = element_text(face = "italic")) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm"))

# Change characters into factors
data_primary_species$Location <- as.factor(data_primary_species$Location)
data_primary_species$Plot <- as.factor(data_primary_species$Plot)
data_primary_species_introduced$Location <- as.factor(data_primary_species_introduced$Location)
data_primary_species_introduced$Plot <- as.factor(data_primary_species_introduced$Plot)
data_primary_species_native$Location <- as.factor(data_primary_species_native$Location)
data_primary_species_native$Plot <- as.factor(data_primary_species_native$Plot)
data_primary_species_woody$Location <- as.factor(data_primary_species_woody$Location)
data_primary_species_woody$Plot <- as.factor(data_primary_species_woody$Plot)
data_primary_species_native_trees$Location <- as.factor(data_primary_species_native_trees$Location)
data_primary_species_native_trees$Plot <- as.factor(data_primary_species_native_trees$Plot)

data_primary_species_no_SP$Location <- as.factor(data_primary_species_no_SP$Location)
data_primary_species_no_SP$Plot <- as.factor(data_primary_species_no_SP$Plot)
data_primary_species_no_SP_introduced$Location <- as.factor(data_primary_species_no_SP_introduced$Location)
data_primary_species_no_SP_introduced$Plot <- as.factor(data_primary_species_no_SP_introduced$Plot)
data_primary_species_no_SP_native$Location <- as.factor(data_primary_species_no_SP_native$Location)
data_primary_species_no_SP_native$Plot <- as.factor(data_primary_species_no_SP_native$Plot)
data_primary_species_no_SP_woody$Location <- as.factor(data_primary_species_no_SP_woody$Location)
data_primary_species_no_SP_woody$Plot <- as.factor(data_primary_species_no_SP_woody$Plot)
data_primary_species_no_SP_native_trees$Location <- as.factor(data_primary_species_no_SP_native_trees$Location)
data_primary_species_no_SP_native_trees$Plot <- as.factor(data_primary_species_no_SP_native_trees$Plot)

# Calculate the mean of community indices for all sites and plot types
aggregate(cbind(species_richness, total_cover, shannon_index, simpson_index) ~ Location, data_primary_species, mean)
aggregate(cbind(species_richness, total_cover, shannon_index, simpson_index) ~ Plot, data_primary_species, mean)

dataset_list <- list(data_primary_species, 
data_primary_species_introduced, 
data_primary_species_native, 
data_primary_species_woody, 
data_primary_species_native_trees)

output <- vector(mode = "list", length = length(dataset_list))

for (df in dataset_list){
  per_location_avg <- aggregate(cbind(species_richness, total_cover, shannon_index, simpson_index) ~ Location, df, mean)
  per_plot_avg <- aggregate(cbind(species_richness, total_cover, shannon_index, simpson_index) ~ Plot, df, mean)
  print(per_location_avg)
  print(per_plot_avg)
}

# **********************************************************************************************************
# RANK ABUNDANCE CURVES
# **********************************************************************************************************
# Split data by field site
rank_abundance_df_all_sites <- data_primary_species
rank_abundance_df_BWNP <- data_primary_species[data_primary_species$Location %in% c("BWNP"), ]
rank_abundance_df_CRAW <- data_primary_species[data_primary_species$Location %in% c("CRAW"), ]
rank_abundance_df_SRNP <- data_primary_species[data_primary_species$Location %in% c("SRNP"), ]

# Remove labeling columns
rank_abundance_df_all_sites <- rank_abundance_df_all_sites[, c(5:136)]
rank_abundance_df_BWNP <- rank_abundance_df_BWNP[, c(5:136)]
rank_abundance_df_CRAW <- rank_abundance_df_CRAW[, c(5:136)]
rank_abundance_df_SRNP <- rank_abundance_df_SRNP[, c(5:136)]

# Calculate rank abundance
rank_abun_all_sites <- data.frame(rankabundance(rank_abundance_df_all_sites))
rank_abun_BWNP <- data.frame(rankabundance(rank_abundance_df_BWNP))
rank_abun_CRAW <- data.frame(rankabundance(rank_abundance_df_CRAW))
rank_abun_SRNP <- data.frame(rankabundance(rank_abundance_df_SRNP))

# Turn the species row name into a column
rank_abun_all_sites <- tibble::rownames_to_column(rank_abun_all_sites, "Plot Type")
rank_abun_BWNP <- tibble::rownames_to_column(rank_abun_BWNP, "Plot Type")
rank_abun_CRAW <- tibble::rownames_to_column(rank_abun_CRAW, "Plot Type")
rank_abun_SRNP <- tibble::rownames_to_column(rank_abun_SRNP, "Plot Type")

# Change "Plot Type" column name to "Species"
names(rank_abun_all_sites)[names(rank_abun_all_sites) == "Plot Type"] <- "Species"
names(rank_abun_BWNP)[names(rank_abun_BWNP) == "Plot Type"] <- "Species"
names(rank_abun_CRAW)[names(rank_abun_CRAW) == "Plot Type"] <- "Species"
names(rank_abun_SRNP)[names(rank_abun_SRNP) == "Plot Type"] <- "Species"

# Replace period in species name with a space
rank_abun_all_sites$Species <- gsub(".", " ", rank_abun_all_sites$Species, fixed = TRUE)
rank_abun_BWNP$Species <- gsub(".", " ", rank_abun_BWNP$Species, fixed = TRUE)
rank_abun_CRAW$Species <- gsub(".", " ", rank_abun_CRAW$Species, fixed = TRUE)
rank_abun_SRNP$Species <- gsub(".", " ", rank_abun_SRNP$Species, fixed = TRUE)

# Turn species name into a factor
rank_abun_all_sites$Species <- as.factor(rank_abun_all_sites$Species)
rank_abun_BWNP$Species <- as.factor(rank_abun_BWNP$Species)
rank_abun_CRAW$Species <- as.factor(rank_abun_CRAW$Species)
rank_abun_SRNP$Species <- as.factor(rank_abun_SRNP$Species)

# Remove columns with 0 abundance
rank_abun_all_sites <- subset(rank_abun_all_sites, abundance > 0)
rank_abun_BWNP <- subset(rank_abun_BWNP, abundance > 0)
rank_abun_CRAW <- subset(rank_abun_CRAW, abundance > 0)
rank_abun_SRNP <- subset(rank_abun_SRNP, abundance > 0)

# Add site label to dataframes
rank_abun_all_sites$Location <- "All"
rank_abun_BWNP$Location <- "BWNP"
rank_abun_CRAW$Location <- "CRAW"
rank_abun_SRNP$Location <- "SRNP"

# Combine individual location dataframes
rank_abun_df <- rbind(rank_abun_BWNP, rank_abun_CRAW, rank_abun_SRNP)

# Subset top species (for labeling)
rank_abun_all_sites_top_7 <- rank_abun_all_sites[1:7, ]
rank_abun_locations_top_3 <- rank_abun_df[c(1:3, 70:72, 123:125), ]

# Diversity indices per field site
# Calculate average percent cover by location
average_percent_cover_all_sites <- as.data.frame(t((colMeans(data_primary_species[, c(5:136)]))))
average_percent_cover_by_site <- aggregate(. ~ Location, data_primary_species[, c(2, 5:136)], mean)

# Calculate species richness
average_percent_cover_all_sites$species_richness <- specnumber(average_percent_cover_all_sites)
average_percent_cover_by_site$Location <- as.character(average_percent_cover_by_site$Location) # switch back to character or the next line won't run
average_percent_cover_by_site$species_richness <- specnumber(average_percent_cover_by_site[2:133])

# Overall Shannon's index
average_percent_cover_all_sites$shannon_index <- diversity(average_percent_cover_all_sites[, 1:132], index = "shannon")
average_percent_cover_by_site$shannon_index <- diversity(average_percent_cover_by_site[, 2:133], index = "shannon")

# Overall Simpson's index
average_percent_cover_all_sites$simpson_index <- diversity(average_percent_cover_all_sites[, 1:132], index = "simpson")
average_percent_cover_by_site$simpson_index <- diversity(average_percent_cover_by_site[, 2:133], index = "simpson")

# Combine with native/invasive categorizations
rank_abun_all_sites <- merge(rank_abun_all_sites, species_info[, 1:2], by = c("Species"))
rank_abun_df <- merge(rank_abun_df, species_info[, 1:2], by = c("Species"))

# Visualize
rank_abun_overall <- ggplot(data = rank_abun_all_sites, aes(x = rank, y = proportion)) +
  geom_line(size = 1) +
  geom_point(size = 3, aes(color = Origin)) +
  labs(x = "Rank", y = "Percent of total cover (%)") +
  theme_classic(base_size = 20) +
  geom_text_repel(
    data = rank_abun_all_sites_top_7,
    aes(label = Species),
    nudge_x = 47, nudge_y = 1,
    fontface = "italic",
    size = 6
  ) +
  geom_text(
    data = average_percent_cover_all_sites, aes(
      x = 120,
      y = 25,
      label = paste("S =", species_richness)
    ),
    size = 6
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  labs(colour = "Origin") +
  scale_color_manual(values = c("#A6385B", "#45C3E6"))

rank_abun_sites <- ggplot(data = rank_abun_df, aes(x = rank, y = proportion)) +
  geom_line(size = 1) +
  geom_point(size = 3, aes(color = Origin)) +
  labs(x = "Rank", y = "Percent of total cover (%)") +
  theme_classic(base_size = 20) +
  facet_grid(Location ~ ., scales = "fixed") +
  geom_text_repel(
    data = rank_abun_locations_top_3,
    aes(label = Species),
    nudge_x = 25, nudge_y = 6,
    fontface = "italic",
    size = 6
  ) +
  geom_text(
    data = average_percent_cover_by_site, aes(
      x = 65,
      y = 45,
      label = paste("S =", species_richness)
    ),
    size = 6
  ) +
  geom_text(
    data = average_percent_cover_by_site, aes(
      x = 65,
      y = 37,
      label = paste("H =", round(shannon_index, 2))
    ),
    size = 6
  ) +
  geom_text(
    data = average_percent_cover_by_site, aes(
      x = 65,
      y = 29,
      label = paste("D =", round(simpson_index, 2))
    ),
    size = 6
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  labs(colour = "Origin") +
  scale_color_manual(values = c("#A6385B", "#45C3E6"))

rank_abun_graph <- ggarrange(rank_abun_overall, rank_abun_sites,
  ncol = 2, nrow = 1,
  hjust = -0.5, vjust = 1.5,
  legend = "bottom",
  common.legend = TRUE,
  labels = "AUTO"
)

ggsave(
  "rank_abun.png",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output",
  plot = rank_abun_graph,
  width = 12,
  height = 6,
  dpi = 300
)

ggsave(
  "NebhutDukes2023_Fig2",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output/EPS",
  plot = rank_abun_graph,
  width = 18,
  height = 8,
  device = cairo_ps
)


# Visualize on a log scale
rank_abun_all_sites$proportion_log <- log(rank_abun_all_sites$proportion + 0.01)
rank_abun_all_sites_top_7$proportion_log <- log(rank_abun_all_sites_top_7$proportion + 0.01)
rank_abun_df$proportion_log <- log(rank_abun_df$proportion + 0.01)
rank_abun_locations_top_3$proportion_log <- log(rank_abun_locations_top_3$proportion + 0.01)

rank_abun_overall_log <- ggplot(data = rank_abun_all_sites, aes(x = rank, y = proportion_log)) +
  geom_line(size = 1) +
  geom_point(size = 3, aes(color = Origin)) +
  labs(x = "Rank", y = "Percent of total cover (%) (log)") +
  theme_classic(base_size = 20) +
  geom_text_repel(
    data = rank_abun_all_sites_top_7,
    aes(label = Species),
    # nudge_x = 47, nudge_y = 1,
    fontface = "italic",
    size = 6
  ) +
  # geom_text(data = average_percent_cover_all_sites, aes(
  #   x = 120,
  #   y = 25,
  #   label = paste("S =", species_richness)
  # ),
  # size = 6) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  labs(colour = "Origin") +
  scale_color_manual(values = c("#A6385B", "#45C3E6"))

rank_abun_sites_log <- ggplot(data = rank_abun_df, aes(x = rank, y = proportion_log)) +
  geom_line(size = 1) +
  geom_point(size = 3, aes(color = Origin)) +
  labs(x = "Rank", y = "Percent of total cover (%) (log)") +
  theme_classic(base_size = 20) +
  facet_grid(Location ~ ., scales = "fixed") +
  geom_text_repel(
    data = rank_abun_locations_top_3,
    aes(label = Species),
    # nudge_x = 25, nudge_y = 6,
    fontface = "italic",
    size = 6
  ) +
  # geom_text(data = average_percent_cover_by_site, aes(
  #   x = 65,
  #   y = 45,
  #   label = paste("S =", species_richness)
  # ),
  # size = 6) +
  # geom_text(data = average_percent_cover_by_site, aes(
  #   x = 65,
  #   y = 37,
  #   label = paste("H =", round(shannon_index, 2))
  # ),
  # size = 6) +
  # geom_text(data = average_percent_cover_by_site, aes(
  #   x = 65,
  #   y = 29,
  #   label = paste("D =", round(simpson_index, 2))
  # ),
  # size = 6) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  labs(colour = "Origin") +
  scale_color_manual(values = c("#A6385B", "#45C3E6"))

rank_abun_graph_log <- ggarrange(rank_abun_overall_log, rank_abun_sites_log,
  ncol = 2, nrow = 1,
  hjust = -0.5, vjust = 1.5,
  legend = "bottom",
  common.legend = TRUE,
  labels = "AUTO"
)

ggsave(
  "rank_abun_log.png",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output",
  plot = rank_abun_graph_log,
  width = 12,
  height = 6,
  dpi = 300
)

ggsave(
  "NebhutDukes2023_Fig2_log",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output/EPS",
  plot = rank_abun_graph_log,
  width = 18,
  height = 8,
  device = cairo_ps
)

# **********************************************************************************************************
# DIVERSITY ANALYSIS: ALL UNDERSTORY SPECIES ####
# **********************************************************************************************************
# Species richness analysis
# W/o DBH
model_richness_all <- lm(data = data_primary_species, species_richness ~ Plot * Location)
plot(model_richness_all) # checking the homogeneity of variances
qqnorm(residuals(model_richness_all)) # checking the normality of the residuals
summary(model_richness_all) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_richness_all) # provides the F, df, and P value for each independent factor
anova_stats(model_richness_all) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_richness_DBH_all <- lm(data = data_primary_species_no_SP, species_richness ~ Plot * DBH * Location)
plot(model_richness_DBH_all) # checking the homogeneity of variances
qqnorm(residuals(model_richness_DBH_all)) # checking the normality of the residuals
summary(model_richness_DBH_all) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_richness_DBH_all) # provides the F, df, and P value for each independent factor
anova_stats(model_richness_DBH_all) # provides the effect size (we are reporting Omega squared)

# Shannon index analysis
# W/o DBH
model_shannon_all <- lm(data = data_primary_species, shannon_index ~ Plot * Location)
plot(model_shannon_all) # checking the homogeneity of variances
qqnorm(residuals(model_shannon_all)) # checking the normality of the residuals
summary(model_shannon_all) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_shannon_all) # provides the F, df, and P value for each independent factor
anova_stats(model_shannon_all) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = data_primary_species, shannon_index ~ Plot * Location))

# Plot Visualization
shannon_all_plot_means <- data.frame(aggregate(shannon_index ~ Plot, data = data_primary_species, FUN = mean)) # calculate mean biomass/m2 in each individual subplot
shannon_all_plot_se <- data.frame(aggregate(shannon_index ~ Plot, data = data_primary_species, FUN = se))
shannon_all_plot_stats <- join_all(list(shannon_all_plot_means, shannon_all_plot_se), by = c("Plot"))
colnames(shannon_all_plot_stats) <- c("Plot", "Mean", "se")

# compact letter display
anova_all_shannon_plot <- aov(data = data_primary_species, shannon_index ~ Plot * Location)
tukey_all_shannon_plot <- TukeyHSD(anova_all_shannon_plot)
cld_all_shannon_plot <- multcompLetters4(anova_all_shannon_plot, tukey_all_shannon_plot)
cld_all_shannon_plot <- as.data.frame.list(cld_all_shannon_plot$Plot)
cld_all_shannon_plot <- cld_all_shannon_plot[sort(row.names(cld_all_shannon_plot)), ]

# plot
all_shannon_plot <- ggplot(data = shannon_all_plot_stats, aes(x = Plot, y = Mean)) +
  geom_point(
    data = data_primary_species, aes(
      x = Plot, y = shannon_index,
      color = Plot, shape = Location
    ),
    position = position_jitter(w = 0.2, h = 0),
    size = 3
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Plot Type") +
  ylab("Shannon index (H)") +
  geom_text(aes(label = cld_all_shannon_plot$Letters),
    y = 2.35,
    size = 5
  ) +
  scale_x_discrete(labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")) +
  theme(
    axis.text.x = element_markdown(),
    legend.text = element_markdown()
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )

# Location Visualization
shannon_all_location_means <- data.frame(aggregate(shannon_index ~ Location, data = data_primary_species, FUN = mean))
shannon_all_location_se <- data.frame(aggregate(shannon_index ~ Location, data = data_primary_species, FUN = se))
shannon_all_location_stats <- join_all(list(shannon_all_location_means, shannon_all_location_se), by = c("Location"))
colnames(shannon_all_location_stats) <- c("Location", "Mean", "se")

# compact letter display
anova_all_shannon_location <- aov(data = data_primary_species, shannon_index ~ Plot * Location)
tukey_all_shannon_location <- TukeyHSD(anova_all_shannon_location)
cld_all_shannon_location <- multcompLetters4(anova_all_shannon_location, tukey_all_shannon_location)
cld_all_shannon_location <- as.data.frame.list(cld_all_shannon_location$Location)
cld_all_shannon_location <- cld_all_shannon_location[sort(row.names(cld_all_shannon_location)), ]

all_shannon_location <- ggplot(data = shannon_all_location_stats, aes(x = Location, y = Mean)) +
  geom_point(
    data = data_primary_species, aes(x = Location, y = shannon_index, color = Plot, shape = Location), position = position_jitter(w = 0.2, h = 0),
    size = 3
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Site") +
  ylab("Shannon index (H)") +
  geom_text(aes(label = cld_all_shannon_location$Letters),
    y = 2.40,
    size = 5
  ) +
  theme(legend.text = element_markdown()) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )

# W/ DBH
model_shannon_DBH_all <- lm(data = data_primary_species_no_SP, shannon_index ~ Plot * DBH * Location)
plot(model_shannon_DBH_all) # checking the homogeneity of variances
qqnorm(residuals(model_shannon_DBH_all)) # checking the normality of the residuals
summary(model_shannon_DBH_all) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_shannon_DBH_all) # provides the F, df, and P value for each independent factor
anova_stats(model_shannon_DBH_all) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = data_primary_species_no_SP, shannon_index ~ Plot * Location))

# Plot Visualization
shannon_all_plot_means_DBH <- data.frame(aggregate(shannon_index ~ Plot, data = data_primary_species_no_SP, FUN = mean)) # calculate mean biomass/m2 in each individual subplot
shannon_all_plot_se_DBH <- data.frame(aggregate(shannon_index ~ Plot, data = data_primary_species_no_SP, FUN = se))
shannon_all_plot_stats_DBH <- join_all(list(shannon_all_plot_means_DBH, shannon_all_plot_se_DBH), by = c("Plot"))
colnames(shannon_all_plot_stats_DBH) <- c("Plot", "Mean", "se")

# compact letter display
anova_all_shannon_plot_DBH <- aov(data = data_primary_species_no_SP, shannon_index ~ Plot * Location * DBH)
tukey_all_shannon_plot_DBH <- TukeyHSD(anova_all_shannon_plot_DBH)
cld_all_shannon_plot_DBH <- multcompLetters4_fixed(anova_all_shannon_plot_DBH, tukey_all_shannon_plot_DBH)
cld_all_shannon_plot_DBH <- as.data.frame.list(cld_all_shannon_plot_DBH$Plot)
cld_all_shannon_plot_DBH <- cld_all_shannon_plot_DBH[sort(row.names(cld_all_shannon_plot_DBH)), ]

# plot
all_shannon_plot_DBH <- ggplot(data = shannon_all_plot_stats_DBH, aes(x = Plot, y = Mean)) +
  geom_point(
    data = data_primary_species_no_SP, aes(
      x = Plot, y = shannon_index,
      color = Plot, shape = Location
    ),
    position = position_jitter(w = 0.2, h = 0),
    size = 3
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Plot Type") +
  ylab("Shannon index (H)") +
  theme(legend.position = "none") +
  geom_text(aes(label = cld_all_shannon_plot_DBH$Letters),
    y = 2.35,
    size = 5
  ) +
  scale_x_discrete(labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*")) +
  theme(
    axis.text.x = element_markdown(),
    legend.text = element_markdown()
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )


# Location Visualization
shannon_all_location_means_DBH <- data.frame(aggregate(shannon_index ~ Location, data = data_primary_species_no_SP, FUN = mean)) # calculate mean biomass/m2 in each individual subplot
shannon_all_location_se_DBH <- data.frame(aggregate(shannon_index ~ Location, data = data_primary_species_no_SP, FUN = se))
shannon_all_location_stats_DBH <- join_all(list(shannon_all_location_means_DBH, shannon_all_location_se_DBH), by = c("Location"))
colnames(shannon_all_location_stats_DBH) <- c("Location", "Mean", "se")

all_shannon_tukey_DBH <- TukeyHSD(aov(data = data_primary_species_no_SP, shannon_index ~ Location))
all_shannon_tukey_location_DBH <- data.frame(all_shannon_tukey_DBH$Location)
all_shannon_tukey_location_p_DBH <- ifelse(all_shannon_tukey_location_DBH$p.adj < 0.01,
  all_shannon_tukey_location_DBH$p.adj <- scientific(all_shannon_tukey_location_DBH$p.adj, digits = 3),
  all_shannon_tukey_location_DBH$p.adj <- round(as.numeric(all_shannon_tukey_location_DBH$p.adj), digits = 2)
)
all_shannon_tukey_location_comparisons <- list(c("CRAW", "BWNP"), c("SRNP", "BWNP"), c("SRNP", "CRAW"))

# compact letter display
anova_all_shannon_location_DBH <- aov(data = data_primary_species_no_SP, shannon_index ~ Plot * Location * DBH)
tukey_all_shannon_location_DBH <- TukeyHSD(anova_all_shannon_location_DBH)
cld_all_shannon_location_DBH <- multcompLetters4_fixed(anova_all_shannon_location_DBH, tukey_all_shannon_location_DBH)
cld_all_shannon_location_DBH <- as.data.frame.list(cld_all_shannon_location_DBH$Location)
cld_all_shannon_location_DBH <- cld_all_shannon_location_DBH[sort(row.names(cld_all_shannon_location_DBH)), ]

all_shannon_location_DBH <- ggplot(data = shannon_all_location_stats_DBH, aes(x = Location, y = Mean)) +
  geom_point(
    data = data_primary_species_no_SP, aes(x = Location, y = shannon_index, color = Plot, shape = Location), position = position_jitter(w = 0.2, h = 0),
    size = 3
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Site") +
  ylab("Shannon index (H)") +
  theme(legend.position = "none") +
  geom_text(aes(label = cld_all_shannon_location_DBH$Letters),
    y = 2.35,
    size = 5
  ) +
  theme(legend.text = element_markdown()) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )

# Simpson index analysis
# W/o DBH
model_simpson_all <- lm(data = data_primary_species, simpson_index ~ Plot * Location)
plot(model_simpson_all) # checking the homogeneity of variances
qqnorm(residuals(model_simpson_all)) # checking the normality of the residuals
summary(model_simpson_all) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_simpson_all) # provides the F, df, and P value for each independent factor
anova_stats(model_simpson_all) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = data_primary_species, simpson_index ~ Plot * Location))

# Plot Visualization
simpson_all_plot_means <- data.frame(aggregate(simpson_index ~ Plot, data = data_primary_species, FUN = mean)) # calculate mean biomass/m2 in each individual subplot
simpson_all_plot_se <- data.frame(aggregate(simpson_index ~ Plot, data = data_primary_species, FUN = se))
simpson_all_plot_stats <- join_all(list(simpson_all_plot_means, simpson_all_plot_se), by = c("Plot"))
colnames(simpson_all_plot_stats) <- c("Plot", "Mean", "se")

all_simpson_tukey <- TukeyHSD(aov(data = data_primary_species, simpson_index ~ Plot * Location))
all_simpson_tukey_plot <- data.frame(all_simpson_tukey$Plot)
all_simpson_tukey_plot_p <- ifelse(all_simpson_tukey_plot$p.adj < 0.05,
  all_simpson_tukey_plot$p.adj <- scientific(all_simpson_tukey_plot$p.adj, digits = 3),
  all_simpson_tukey_plot$p.adj <- round(as.numeric(all_simpson_tukey_plot$p.adj), digits = 2)
)
all_simpson_tukey_plot_comparisons <- list(
  c("PLOC", "LITU"), c("PYCA80", "LITU"), c("SP", "LITU"),
  c("PYCA80", "PLOC"), c("SP", "PLOC"), c("SP", "PYCA80")
)

# compact letters display
anova_all_simpson_plot <- aov(data = data_primary_species, simpson_index ~ Plot * Location)
tukey_all_simpson_plot <- TukeyHSD(anova_all_simpson_plot)
cld_all_simpson_plot <- multcompLetters4(anova_all_simpson_plot, tukey_all_simpson_plot)
cld_all_simpson_plot <- as.data.frame.list(cld_all_simpson_plot$Plot)
cld_all_simpson_plot <- cld_all_simpson_plot[sort(row.names(cld_all_simpson_plot)), ]

all_simpson_plot <- ggplot(data = simpson_all_plot_stats, aes(x = Plot, y = Mean)) +
  geom_point(
    data = data_primary_species, aes(x = Plot, y = simpson_index, color = Plot, shape = Location), position = position_jitter(w = 0.2, h = 0),
    size = 3
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Plot Type") +
  ylab("Simpson index (D)") +
  theme(legend.position = "none") +
  geom_text(aes(label = cld_all_simpson_plot$Letters),
    y = 1,
    size = 5
  ) +
  scale_x_discrete(labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")) +
  coord_cartesian(
    ylim = c(0, 1),
  ) +
  theme(
    axis.text.x = element_markdown(),
    legend.text = element_markdown()
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )

# Location Visualization
simpson_all_location_means <- data.frame(aggregate(simpson_index ~ Location, data = data_primary_species, FUN = mean)) # calculate mean biomass/m2 in each individual subplot
simpson_all_location_se <- data.frame(aggregate(simpson_index ~ Location, data = data_primary_species, FUN = se))
simpson_all_location_stats <- join_all(list(simpson_all_location_means, simpson_all_location_se), by = c("Location"))
colnames(simpson_all_location_stats) <- c("Location", "Mean", "se")

all_simpson_tukey <- TukeyHSD(aov(data = data_primary_species, simpson_index ~ Location))
all_simpson_tukey_location <- data.frame(all_simpson_tukey$Location)
all_simpson_tukey_location_p <- ifelse(all_simpson_tukey_location$p.adj < 0.01,
  all_simpson_tukey_location$p.adj <- scientific(all_simpson_tukey_location$p.adj, digits = 3),
  all_simpson_tukey_location$p.adj <- round(as.numeric(all_simpson_tukey_location$p.adj), digits = 2)
)
all_simpson_tukey_location_comparisons <- list(c("CRAW", "BWNP"), c("SRNP", "BWNP"), c("SRNP", "CRAW"))

# compact letter display
anova_all_simpson_location <- aov(data = data_primary_species, simpson_index ~ Plot * Location)
tukey_all_simpson_location <- TukeyHSD(anova_all_simpson_plot)
cld_all_simpson_location <- multcompLetters4(anova_all_simpson_plot, tukey_all_simpson_plot)
cld_all_simpson_location <- as.data.frame.list(cld_all_simpson_location$Location)
cld_all_simpson_location <- cld_all_simpson_location[sort(row.names(cld_all_simpson_location)), ]

all_simpson_location <- ggplot(data = simpson_all_location_stats, aes(x = Location, y = Mean)) +
  geom_point(
    data = data_primary_species, aes(x = Location, y = simpson_index, color = Plot, shape = Location), position = position_jitter(w = 0.2, h = 0),
    size = 3
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Site") +
  ylab("Simpson index (D)") +
  geom_text(aes(label = cld_all_simpson_location$Letters),
    y = 0.98,
    size = 5
  ) +
  coord_cartesian(ylim = c(0, 1)) +
  theme(
    axis.text.x = element_markdown(),
    legend.text = element_markdown()
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )

# W/ DBH
model_simpson_all_DBH <- lm(data = data_primary_species_no_SP, simpson_index ~ Plot * Location * DBH)
plot(model_simpson_all_DBH) # checking the homogeneity of variances
qqnorm(residuals(model_simpson_all_DBH)) # checking the normality of the residuals
summary(model_simpson_all_DBH) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_simpson_all_DBH) # provides the F, df, and P value for each independent factor
anova_stats(model_simpson_all_DBH) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = data_primary_species_no_SP, simpson_index ~ Plot * Location * DBH))

# Total cover analysis
# W/o DBH
model_total_cover_all <- lm(data = data_primary_species, total_cover ~ Plot * Location)
plot(model_total_cover_all) # checking the homogeneity of variances
qqnorm(residuals(model_total_cover_all)) # checking the normality of the residuals
summary(model_total_cover_all) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_total_cover_all) # provides the F, df, and P value for each independent factor
anova_stats(model_total_cover_all) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_total_cover_all_DBH <- lm(data = data_primary_species_no_SP, total_cover ~ Plot * DBH * Location)
plot(model_total_cover_all_DBH) # checking the homogeneity of variances
qqnorm(residuals(model_total_cover_all_DBH)) # checking the normality of the residuals
summary(model_total_cover_all_DBH) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_total_cover_all_DBH) # provides the F, df, and P value for each independent factor
anova_stats(model_total_cover_all_DBH) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = data_primary_species_no_SP, total_cover ~ Plot * DBH * Location))

# Plot Visualization
total_cover_all_plot_means <- data.frame(aggregate(total_cover ~ Plot, data = data_primary_species_no_SP, FUN = mean)) # calculate mean biomass/m2 in each individual subplot
total_cover_all_plot_se <- data.frame(aggregate(total_cover ~ Plot, data = data_primary_species_no_SP, FUN = se))
total_cover_all_plot_stats <- join_all(list(total_cover_all_plot_means, total_cover_all_plot_se), by = c("Plot"))
colnames(total_cover_all_plot_stats) <- c("Plot", "Mean", "se")

all_total_cover_tukey <- TukeyHSD(aov(data = data_primary_species_no_SP, total_cover ~ Plot * Location))
all_total_cover_tukey_plot <- data.frame(all_total_cover_tukey$Plot)
all_total_cover_tukey_plot_p <- ifelse(all_total_cover_tukey_plot$p.adj < 0.05,
  all_total_cover_tukey_plot$p.adj <- scientific(all_total_cover_tukey_plot$p.adj, digits = 3),
  all_total_cover_tukey_plot$p.adj <- round(as.numeric(all_total_cover_tukey_plot$p.adj), digits = 2)
)
all_total_cover_tukey_plot_comparisons <- list(c("PLOC", "LITU"), c("PYCA80", "LITU"), c("PYCA80", "PLOC"))

# compact letter display
anova_all_total_cover_plot_DBH <- aov(data = data_primary_species_no_SP, total_cover ~ Plot * Location * DBH)
tukey_all_total_cover_plot_DBH <- TukeyHSD(anova_all_total_cover_plot_DBH)
cld_all_total_cover_plot_DBH <- multcompLetters4_fixed(anova_all_total_cover_plot_DBH, tukey_all_total_cover_plot_DBH)
cld_all_total_cover_plot_DBH <- as.data.frame.list(cld_all_total_cover_plot_DBH$Plot)
cld_all_total_cover_plot_DBH <- cld_all_total_cover_plot_DBH[sort(row.names(cld_all_total_cover_plot_DBH)), ]

all_total_cover_plot <- ggplot(data = total_cover_all_plot_stats, aes(x = Plot, y = Mean)) +
  geom_point(
    data = data_primary_species_no_SP, aes(x = Plot, y = total_cover, color = Plot, shape = Location), position = position_jitter(w = 0.2, h = 0),
    size = 3
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Plot Type") +
  ylab("Total Cover (%)") +
  scale_x_discrete(labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*")) +
  geom_text(aes(label = cld_all_total_cover_plot_DBH$Letters),
    y = 210,
    size = 5
  ) +
  coord_cartesian(ylim = c(20, 215)) +
  theme(
    axis.text.x = element_markdown(),
    legend.text = element_markdown()
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )

# Location Visualization
total_cover_all_location_means <- data.frame(aggregate(total_cover ~ Location, data = data_primary_species_no_SP, FUN = mean)) # calculate mean biomass/m2 in each individual subplot
total_cover_all_location_se <- data.frame(aggregate(total_cover ~ Location, data = data_primary_species_no_SP, FUN = se))
total_cover_all_location_stats <- join_all(list(total_cover_all_location_means, total_cover_all_location_se), by = c("Location"))
colnames(total_cover_all_location_stats) <- c("Location", "Mean", "se")

all_total_cover_tukey <- TukeyHSD(aov(data = data_primary_species_no_SP, total_cover ~ Location))
all_total_cover_tukey_location <- data.frame(all_total_cover_tukey$Location)
all_total_cover_tukey_location_p <- ifelse(all_total_cover_tukey_location$p.adj < 0.01,
  all_total_cover_tukey_location$p.adj <- scientific(all_total_cover_tukey_location$p.adj, digits = 3),
  all_total_cover_tukey_location$p.adj <- round(as.numeric(all_total_cover_tukey_location$p.adj), digits = 2)
)
all_total_cover_tukey_location_comparisons <- list(c("CRAW", "BWNP"), c("SRNP", "BWNP"), c("SRNP", "CRAW"))

# compact letter display
anova_all_total_cover_location_DBH <- aov(data = data_primary_species_no_SP, total_cover ~ Plot * Location * DBH)
tukey_all_total_cover_location_DBH <- TukeyHSD(anova_all_total_cover_location_DBH)
cld_all_total_cover_location_DBH <- multcompLetters4_fixed(anova_all_total_cover_location_DBH, tukey_all_total_cover_location_DBH)
cld_all_total_cover_location_DBH <- as.data.frame.list(cld_all_total_cover_location_DBH$Location)
cld_all_total_cover_location_DBH <- cld_all_total_cover_location_DBH[sort(row.names(cld_all_total_cover_location_DBH)), ]

all_total_cover_location <- ggplot(data = total_cover_all_location_stats, aes(x = Location, y = Mean)) +
  geom_point(
    data = data_primary_species_no_SP, aes(x = Location, y = total_cover, color = Plot, shape = Location), position = position_jitter(w = 0.2, h = 0),
    size = 3
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Site") +
  ylab("Total Cover (%)") +
  geom_text(aes(label = cld_all_total_cover_location_DBH$Letters),
    y = 210,
    size = 5
  ) +
  coord_cartesian(ylim = c(20, 215)) +
  theme(
    axis.text.x = element_markdown(),
    legend.text = element_markdown()
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )

# Combine plots
# Shannon index
Shannon_All <- ggarrange(all_shannon_plot, all_shannon_location,
  ncol = 2, nrow = 1,
  hjust = -0.5, vjust = 1.5,
  common.legend = TRUE,
  legend = "bottom",
  labels = "AUTO"
)

ggsave(
  "Shannon_All.png",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output",
  plot = Shannon_All,
  width = 12,
  height = 5,
  dpi = 300
)

ggsave(
  "NebhutDukes2023_Fig3",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output/EPS",
  plot = Shannon_All,
  width = 12,
  height = 5,
  device = cairo_ps
)

# Simpson index
Simpson_All <- ggarrange(all_simpson_plot, all_simpson_location,
  ncol = 2, nrow = 1,
  hjust = -0.5, vjust = 1.5,
  legend = "bottom",
  common.legend = TRUE,
  labels = "AUTO"
)

ggsave(
  "Simpson_All.png",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output",
  plot = Simpson_All,
  width = 12,
  height = 5,
  dpi = 300
)

ggsave(
  "NebhutDukes2023_Fig4",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output/EPS",
  plot = Simpson_All,
  width = 12,
  height = 5,
  device = cairo_ps
)

# DBH Total Cover
DBH_Total_Cover_All <- ggarrange(all_total_cover_plot, all_total_cover_location,
  ncol = 2, nrow = 1,
  hjust = -0.5, vjust = 1.5,
  legend = "bottom",
  common.legend = TRUE,
  labels = "AUTO"
)

ggsave(
  "DBH_Total_Cover_All.png",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output",
  plot = DBH_Total_Cover_All,
  width = 12,
  height = 5,
  dpi = 300
)

ggsave(
  "NebhutDukes2023_FigS2",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output/EPS",
  plot = DBH_Total_Cover_All,
  width = 12,
  height = 5,
  device = cairo_ps
)

# DBH Shannon's
DBH_Shannon_All <- ggarrange(all_shannon_plot_DBH, all_shannon_location_DBH,
  ncol = 2, nrow = 1,
  hjust = -0.5, vjust = 1.5,
  legend = "bottom",
  common.legend = TRUE,
  labels = "AUTO"
)

ggsave(
  "DBH_Shannon_All.png",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output",
  plot = DBH_Shannon_All,
  width = 12,
  height = 5,
  dpi = 300
)

ggsave(
  "NebhutDukes2023_FigS3",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output/EPS",
  plot = DBH_Shannon_All,
  width = 12,
  height = 5,
  device = cairo_ps
)

# **********************************************************************************************************
# DIVERSITY ANALYSIS: INTRODUCED SPECIES ####
# **********************************************************************************************************
# Species richness analysis
# W/o DBH
model_richness_introduced <- lm(data = data_primary_species_introduced, species_richness ~ Plot * Location)
plot(model_richness_introduced) # checking the homogeneity of variances
qqnorm(residuals(model_richness_introduced)) # checking the normality of the residuals
summary(model_richness_introduced) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_richness_introduced) # provides the F, df, and P value for each independent factor
anova_stats(model_richness_introduced) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_richness_DBH_introduced <- lm(data = data_primary_species_no_SP_introduced, species_richness ~ Plot * DBH * Location)
plot(model_richness_DBH_introduced) # checking the homogeneity of variances
qqnorm(residuals(model_richness_DBH_introduced)) # checking the normality of the residuals
summary(model_richness_DBH_introduced) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_richness_DBH_introduced) # provides the F, df, and P value for each independent factor
anova_stats(model_richness_DBH_introduced) # provides the effect size (we are reporting Omega squared)

# Shannon index analysis
# W/o DBH
model_shannon_introduced <- lm(data = data_primary_species_introduced, shannon_index ~ Plot * Location)
plot(model_shannon_introduced) # checking the homogeneity of variances
qqnorm(residuals(model_shannon_introduced)) # checking the normality of the residuals
summary(model_shannon_introduced) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_shannon_introduced) # provides the F, df, and P value for each independent factor
anova_stats(model_shannon_introduced) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_shannon_DBH_introduced <- lm(data = data_primary_species_no_SP_introduced, shannon_index ~ Plot * DBH * Location)
plot(model_shannon_DBH_introduced) # checking the homogeneity of variances
qqnorm(residuals(model_shannon_DBH_introduced)) # checking the normality of the residuals
summary(model_shannon_DBH_introduced) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_shannon_DBH_introduced) # provides the F, df, and P value for each independent factor
anova_stats(model_shannon_DBH_introduced) # provides the effect size (we are reporting Omega squared)

# Simpson index analysis
# W/o DBH
model_simpson_introduced <- lm(data = data_primary_species_introduced, simpson_index ~ Plot * Location)
plot(model_simpson_introduced) # checking the homogeneity of variances
qqnorm(residuals(model_simpson_introduced)) # checking the normality of the residuals
summary(model_simpson_introduced) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_simpson_introduced) # provides the F, df, and P value for each independent factor
anova_stats(model_simpson_introduced) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_simpson_DBH_introduced <- lm(data = data_primary_species_no_SP_introduced, simpson_index ~ Plot * Location * DBH)
plot(model_simpson_DBH_introduced) # checking the homogeneity of variances
qqnorm(residuals(model_simpson_DBH_introduced)) # checking the normality of the residuals
summary(model_simpson_DBH_introduced) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_simpson_DBH_introduced) # provides the F, df, and P value for each independent factor
anova_stats(model_simpson_DBH_introduced) # provides the effect size (we are reporting Omega squared)

# Total cover analysis
# W/o DBH
model_total_cover_introduced <- lm(data = data_primary_species_introduced, total_cover ~ Plot * Location)
plot(model_total_cover_introduced) # checking the homogeneity of variances
qqnorm(residuals(model_total_cover_introduced)) # checking the normality of the residuals
summary(model_total_cover_introduced) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_total_cover_introduced) # provides the F, df, and P value for each independent factor
anova_stats(model_total_cover_introduced) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_total_cover_introduced_DBH <- lm(data = data_primary_species_no_SP_introduced, total_cover ~ Plot * DBH * Location)
plot(model_total_cover_introduced_DBH) # checking the homogeneity of variances
qqnorm(residuals(model_total_cover_introduced_DBH)) # checking the normality of the residuals
summary(model_total_cover_introduced_DBH) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_total_cover_introduced_DBH) # provides the F, df, and P value for each independent factor
anova_stats(model_total_cover_introduced_DBH) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = data_primary_species, total_cover ~ Plot * DBH * Location))

# Visualization (plot * DBH * location)
species_names <- c(
  `LITU` = "L. tulipifera",
  `PLOC` = "P. occidentalis",
  `PYCA80` = "P. calleryana",
  `BWNP` = "BWNP",
  `CRAW` = "CRAW",
  `SRNP` = "SRNP"
)

ggplot(data = data_primary_species_no_SP_introduced, aes(x = DBH, y = total_cover)) +
  geom_smooth(method = "lm", color = "black") +
  geom_point(size = 1, alpha = 1, aes(color = Plot, shape = Location)) +
  theme_classic(base_size = 18) +
  xlab("DBH (in)") +
  ylab("Invasive Cover (%)") +
  facet_grid(Location ~ Plot, labeller = as_labeller(species_names)) +
  theme(strip.text.x = element_text(face = "italic")) +
  stat_regline_equation(label.x = 0.2, label.y = 150, color = "black") +
  stat_cor(label.x = 0.2, label.y = 125, color = "black") +
  theme(legend.text = element_text(face = "italic")) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("L. tulipifera", "P. occidentalis", "P. calleryana", "Control")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )


# **********************************************************************************************************
# DIVERSITY ANALYSIS: NATIVE SPECIES ####
# **********************************************************************************************************
# Species richness analysis
# W/o DBH
model_richness_native <- lm(data = data_primary_species_native, species_richness ~ Plot * Location)
plot(model_richness_native) # checking the homogeneity of variances
qqnorm(residuals(model_richness_native)) # checking the normality of the residuals
summary(model_richness_native) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_richness_native) # provides the F, df, and P value for each independent factor
anova_stats(model_richness_native) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_richness_DBH_native <- lm(data = data_primary_species_no_SP_native, species_richness ~ Plot * DBH * Location)
plot(model_richness_DBH_native) # checking the homogeneity of variances
qqnorm(residuals(model_richness_DBH_native)) # checking the normality of the residuals
summary(model_richness_DBH_native) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_richness_DBH_native) # provides the F, df, and P value for each independent factor
anova_stats(model_richness_DBH_native) # provides the effect size (we are reporting Omega squared)

# Shannon index analysis
# W/o DBH
model_shannon_native <- lm(data = data_primary_species_native, shannon_index ~ Plot * Location)
plot(model_shannon_native) # checking the homogeneity of variances
qqnorm(residuals(model_shannon_native)) # checking the normality of the residuals
summary(model_shannon_native) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_shannon_native) # provides the F, df, and P value for each independent factor
anova_stats(model_shannon_native) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_shannon_DBH_native <- lm(data = data_primary_species_no_SP_native, shannon_index ~ Plot * DBH * Location)
plot(model_shannon_DBH_native) # checking the homogeneity of variances
qqnorm(residuals(model_shannon_DBH_native)) # checking the normality of the residuals
summary(model_shannon_DBH_native) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_shannon_DBH_native) # provides the F, df, and P value for each independent factor
anova_stats(model_shannon_DBH_native) # provides the effect size (we are reporting Omega squared)

# Plot Visualization
shannon_native_plot_means <- data.frame(aggregate(shannon_index ~ Plot, data = data_primary_species_no_SP_native, FUN = mean)) # calculate mean biomass/m2 in each individual subplot
shannon_native_plot_se <- data.frame(aggregate(shannon_index ~ Plot, data = data_primary_species_no_SP_native, FUN = se))
shannon_native_plot_stats <- join_all(list(shannon_native_plot_means, shannon_native_plot_se), by = c("Plot"))
colnames(shannon_native_plot_stats) <- c("Plot", "Mean", "se")

shannon_native_tukey <- TukeyHSD(aov(data = data_primary_species_no_SP_native, shannon_index ~ Plot * Location))
shannon_native_tukey_plot <- data.frame(shannon_native_tukey$Plot)
shannon_native_tukey_plot_p <- ifelse(shannon_native_tukey_plot$p.adj < 0.05,
  shannon_native_tukey_plot$p.adj <- scientific(shannon_native_tukey_plot$p.adj, digits = 3),
  shannon_native_tukey_plot$p.adj <- round(as.numeric(shannon_native_tukey_plot$p.adj), digits = 2)
)
shannon_native_tukey_plot_comparisons <- list(c("PLOC", "LITU"), c("PYCA80", "LITU"), c("PYCA80", "PLOC"))

# compact letter display
anova_all_shannon_plot_DBH <- aov(data = data_primary_species_no_SP_native, shannon_index ~ Plot * Location * DBH)
tukey_all_shannon_plot_DBH <- TukeyHSD(anova_all_shannon_plot_DBH)
cld_all_shannon_plot_DBH <- multcompLetters4_fixed(anova_all_shannon_plot_DBH, tukey_all_shannon_plot_DBH)
cld_all_shannon_plot_DBH <- as.data.frame.list(cld_all_shannon_plot_DBH$Plot)
cld_all_shannon_plot_DBH <- cld_all_shannon_plot_DBH[sort(row.names(cld_all_shannon_plot_DBH)), ]

shannon_native_plot <- ggplot(data = shannon_native_plot_stats, aes(x = Plot, y = Mean)) +
  geom_point(
    data = data_primary_species_no_SP_native, aes(x = Plot, y = shannon_index, color = Plot, shape = Location), position = position_jitter(w = 0.2, h = 0),
    size = 3
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Plot Type") +
  ylab("Native community\nShannon's index (H)") +
  scale_x_discrete(labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*")) +
  geom_text(aes(label = cld_all_shannon_plot_DBH$Letters),
    y = 2.5,
    size = 5
  ) +
  coord_cartesian(ylim = c(0, 2.5)) +
  theme(
    legend.text = element_markdown(),
    axis.text.x = element_markdown()
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )

# Location Visualization
shannon_native_location_means <- data.frame(aggregate(shannon_index ~ Location, data = data_primary_species_no_SP_native, FUN = mean)) # calculate mean biomass/m2 in each individual subplot
shannon_native_location_se <- data.frame(aggregate(shannon_index ~ Location, data = data_primary_species_no_SP_native, FUN = se))
shannon_native_location_stats <- join_all(list(shannon_native_location_means, shannon_native_location_se), by = c("Location"))
colnames(shannon_native_location_stats) <- c("Location", "Mean", "se")

shannon_native_tukey <- TukeyHSD(aov(data = data_primary_species_no_SP_native, shannon_index ~ Location))
shannon_native_tukey_location <- data.frame(shannon_native_tukey$Location)
shannon_native_tukey_location_p <- ifelse(shannon_native_tukey_location$p.adj < 0.01,
  shannon_native_tukey_location$p.adj <- scientific(shannon_native_tukey_location$p.adj, digits = 3),
  shannon_native_tukey_location$p.adj <- round(as.numeric(shannon_native_tukey_location$p.adj), digits = 2)
)
shannon_native_tukey_location_comparisons <- list(c("CRAW", "BWNP"), c("SRNP", "BWNP"), c("SRNP", "CRAW"))

# compact letter display
anova_all_shannon_location_DBH <- aov(data = data_primary_species_no_SP_native, shannon_index ~ Plot * Location * DBH)
tukey_all_shannon_location_DBH <- TukeyHSD(anova_all_shannon_location_DBH)
cld_all_shannon_location_DBH <- multcompLetters4_fixed(anova_all_shannon_location_DBH, tukey_all_shannon_location_DBH)
cld_all_shannon_location_DBH <- as.data.frame.list(cld_all_shannon_location_DBH$Location)
cld_all_shannon_location_DBH <- cld_all_shannon_location_DBH[sort(row.names(cld_all_shannon_location_DBH)), ]

shannon_native_location <- ggplot(data = shannon_native_location_stats, aes(x = Location, y = Mean)) +
  geom_point(
    data = data_primary_species_no_SP_native, aes(x = Location, y = shannon_index, color = Plot, shape = Location), position = position_jitter(w = 0.2, h = 0),
    size = 3
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Site") +
  ylab("Native community\nShannon's index (H)") +
  geom_text(aes(label = cld_all_shannon_location_DBH$Letters),
    y = 2.5,
    size = 5
  ) +
  coord_cartesian(ylim = c(0, 2.5)) +
  theme(legend.text = element_markdown()) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )

# Native community Shannon Index
Shannon_Native <- ggarrange(shannon_native_plot, shannon_native_location,
  common.legend = TRUE,
  labels = "AUTO",
  ncol = 2, nrow = 1,
  hjust = -0.5, vjust = 1.5,
  legend = "bottom"
)

ggsave(
  "Shannon_Native.png",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output",
  plot = Shannon_Native,
  width = 12,
  height = 5,
  dpi = 300
)

ggsave(
  "NebhutDukes2023_FigS5",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output/EPS",
  plot = Shannon_Native,
  width = 12,
  height = 5,
  device = cairo_ps
)

# Simpson index analysis
# W/o DBH
model_simpson_native <- lm(data = data_primary_species_native, simpson_index ~ Plot * Location)
plot(model_simpson_native) # checking the homogeneity of variances
qqnorm(residuals(model_simpson_native)) # checking the normality of the residuals
summary(model_simpson_native) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_simpson_native) # provides the F, df, and P value for each independent factor
anova_stats(model_simpson_native) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_simpson_DBH_native <- lm(data = data_primary_species_no_SP_native, simpson_index ~ Plot * Location * DBH)
plot(model_simpson_DBH_native) # checking the homogeneity of variances
qqnorm(residuals(model_simpson_DBH_native)) # checking the normality of the residuals
summary(model_simpson_DBH_native) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_simpson_DBH_native) # provides the F, df, and P value for each independent factor
anova_stats(model_simpson_DBH_native) # provides the effect size (we are reporting Omega squared)

# Total cover analysis
# W/o DBH
model_total_cover_native <- lm(data = data_primary_species_native, total_cover ~ Plot * Location)
plot(model_total_cover_native) # checking the homogeneity of variances
qqnorm(residuals(model_total_cover_native)) # checking the normality of the residuals
summary(model_total_cover_native) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_total_cover_native) # provides the F, df, and P value for each independent factor
anova_stats(model_total_cover_native) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_total_cover_native_DBH <- lm(data = data_primary_species_no_SP_native, total_cover ~ Plot * DBH * Location)
plot(model_total_cover_native_DBH) # checking the homogeneity of variances
qqnorm(residuals(model_total_cover_native_DBH)) # checking the normality of the residuals
summary(model_total_cover_native_DBH) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_total_cover_native_DBH) # provides the F, df, and P value for each independent factor
anova_stats(model_total_cover_native_DBH) # provides the effect size (we are reporting Omega squared)


# **********************************************************************************************************
# DIVERSITY ANALYSIS: WOODY SPECIES ####
# **********************************************************************************************************
# Species richness
# W/o DBH
model_richness_woody <- lm(data = data_primary_species_woody, species_richness ~ Plot * Location)
plot(model_richness_woody) # checking the homogeneity of variances
qqnorm(residuals(model_richness_woody)) # checking the normality of the residuals
summary(model_richness_woody) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_richness_woody) # provides the F, df, and P value for each independent factor
anova_stats(model_richness_woody) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_richness_DBH_woody <- lm(data = data_primary_species_no_SP_woody, species_richness ~ Plot * DBH * Location)
plot(model_richness_DBH_woody) # checking the homogeneity of variances
qqnorm(residuals(model_richness_DBH_woody)) # checking the normality of the residuals
summary(model_richness_DBH_woody) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_richness_DBH_woody) # provides the F, df, and P value for each independent factor
anova_stats(model_richness_DBH_woody) # provides the effect size (we are reporting Omega squared)

# Shannon index analysis
# W/o DBH
model_shannon_woody <- lm(data = data_primary_species_woody, shannon_index ~ Plot * Location)
plot(model_shannon_woody) # checking the homogeneity of variances
qqnorm(residuals(model_shannon_woody)) # checking the normality of the residuals
summary(model_shannon_woody) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_shannon_woody) # provides the F, df, and P value for each independent factor
anova_stats(model_shannon_woody) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_shannon_DBH_woody <- lm(data = data_primary_species_no_SP_woody, shannon_index ~ Plot * DBH * Location)
plot(model_shannon_DBH_woody) # checking the homogeneity of variances
qqnorm(residuals(model_shannon_DBH_woody)) # checking the normality of the residuals
summary(model_shannon_DBH_woody) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_shannon_DBH_woody) # provides the F, df, and P value for each independent factor
anova_stats(model_shannon_DBH_woody) # provides the effect size (we are reporting Omega squared)

# Simpson index analysis
# W/o DBH
model_simpson_woody <- lm(data = data_primary_species_woody, simpson_index ~ Plot * Location)
plot(model_simpson_woody) # checking the homogeneity of variances
qqnorm(residuals(model_simpson_woody)) # checking the normality of the residuals
summary(model_simpson_woody) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_simpson_woody) # provides the F, df, and P value for each independent factor
anova_stats(model_simpson_woody) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_simpson_DBH_woody <- lm(data = data_primary_species_no_SP_woody, simpson_index ~ Plot * Location * DBH)
plot(model_simpson_DBH_woody) # checking the homogeneity of variances
qqnorm(residuals(model_simpson_DBH_woody)) # checking the normality of the residuals
summary(model_simpson_DBH_woody) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_simpson_DBH_woody) # provides the F, df, and P value for each independent factor
anova_stats(model_simpson_DBH_woody) # provides the effect size (we are reporting Omega squared)

# Total cover analysis
# W/o DBH
model_total_cover_woody <- lm(data = data_primary_species_woody, total_cover ~ Plot * Location)
plot(model_total_cover_woody) # checking the homogeneity of variances
qqnorm(residuals(model_total_cover_woody)) # checking the normality of the residuals
summary(model_total_cover_woody) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_total_cover_woody) # provides the F, df, and P value for each independent factor
anova_stats(model_total_cover_woody) # provides the effect size (we are reporting Omega squared)

# Plot Visualization
woody_cover_plot_means <- data.frame(aggregate(total_cover ~ Plot, data = data_primary_species_woody, FUN = mean))
woody_cover_plot_se <- data.frame(aggregate(total_cover ~ Plot, data = data_primary_species_woody, FUN = se))
woody_cover_plot_stats <- join_all(list(woody_cover_plot_means, woody_cover_plot_se), by = c("Plot"))
colnames(woody_cover_plot_stats) <- c("Plot", "Mean", "se")

woody_cover_tukey <- TukeyHSD(aov(data = data_primary_species_woody, total_cover ~ Plot * Location))
woody_cover_tukey_plot <- data.frame(woody_cover_tukey$Plot)
woody_cover_tukey_plot_p <- ifelse(woody_cover_tukey_plot$p.adj < 0.05,
  woody_cover_tukey_plot$p.adj <- scientific(woody_cover_tukey_plot$p.adj, digits = 3),
  woody_cover_tukey_plot$p.adj <- round(as.numeric(woody_cover_tukey_plot$p.adj), digits = 2)
)
woody_cover_tukey_plot_comparisons <- list(
  c("PLOC", "LITU"), c("PYCA80", "LITU"), c("SP", "LITU"),
  c("PYCA80", "PLOC"), c("SP", "PLOC"), c("SP", "PYCA80")
)

# compact letter display
anova_woody_TC_plot <- aov(data = data_primary_species_woody, total_cover ~ Plot * Location)
tukey_woody_TC_plot <- TukeyHSD(anova_woody_TC_plot)
cld_woody_TC_plot <- multcompLetters4_fixed(anova_woody_TC_plot, tukey_woody_TC_plot)
cld_woody_TC_plot <- as.data.frame.list(cld_woody_TC_plot$Plot)
cld_woody_TC_plot <- cld_woody_TC_plot[sort(row.names(cld_woody_TC_plot)), ]

# plot
woody_cover_plot <- ggplot(data = woody_cover_plot_stats, aes(x = Plot, y = Mean)) +
  geom_point(
    data = data_primary_species_woody, aes(x = Plot, y = total_cover, color = Plot, shape = Location), position = position_jitter(w = 0.2, h = 0),
    size = 3
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Plot Type") +
  ylab("Woody cover (%)") +
  scale_x_discrete(labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")) +
  geom_text(aes(label = cld_woody_TC_plot$Letters),
    y = 130,
    size = 5
  ) +
  coord_cartesian(ylim = c(0, 130)) +
  theme(
    axis.text.x = element_markdown(),
    legend.text = element_markdown()
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  )

# Location Visualization
woody_cover_location_means <- data.frame(aggregate(total_cover ~ Location, data = data_primary_species_woody, FUN = mean)) # calculate mean biomass/m2 in each individual subplot
woody_cover_location_se <- data.frame(aggregate(total_cover ~ Location, data = data_primary_species_woody, FUN = se))
woody_cover_location_stats <- join_all(list(woody_cover_location_means, woody_cover_location_se), by = c("Location"))
colnames(woody_cover_location_stats) <- c("Location", "Mean", "se")

woody_cover_tukey <- TukeyHSD(aov(data = data_primary_species_woody, total_cover ~ Location))
woody_cover_tukey_location <- data.frame(woody_cover_tukey$Location)
woody_cover_tukey_location_p <- ifelse(woody_cover_tukey_location$p.adj < 0.01,
  woody_cover_tukey_location$p.adj <- scientific(woody_cover_tukey_location$p.adj, digits = 3),
  woody_cover_tukey_location$p.adj <- round(as.numeric(woody_cover_tukey_location$p.adj), digits = 2)
)
woody_cover_tukey_location_comparisons <- list(c("CRAW", "BWNP"), c("SRNP", "BWNP"), c("SRNP", "CRAW"))

# compact letter display
anova_woody_TC_location <- aov(data = data_primary_species_woody, total_cover ~ Plot * Location)
tukey_woody_TC_location <- TukeyHSD(anova_woody_TC_location)
cld_woody_TC_location <- multcompLetters4_fixed(anova_woody_TC_location, tukey_woody_TC_location)
cld_woody_TC_location <- as.data.frame.list(cld_woody_TC_location$Location)
cld_woody_TC_location <- cld_woody_TC_location[sort(row.names(cld_woody_TC_location)), ]

woody_cover_location <- ggplot(data = woody_cover_location_stats, aes(x = Location, y = Mean)) +
  geom_point(
    data = data_primary_species_woody, aes(x = Location, y = total_cover, color = Plot, shape = Location), position = position_jitter(w = 0.2, h = 0),
    size = 3
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Site") +
  ylab("Woody cover (%)") +
  geom_text(aes(label = cld_woody_TC_location$Letters),
    y = 130,
    size = 5
  ) +
  coord_cartesian(ylim = c(0, 130)) +
  theme(legend.text = element_markdown()) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  )

# Total Cover
woody_cover <- ggarrange(woody_cover_plot, woody_cover_location,
  ncol = 2, nrow = 1,
  hjust = -0.5, vjust = 1.5,
  legend = "bottom",
  common.legend = TRUE,
  labels = "AUTO"
)

ggsave(
  "woody_total_cover.png",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output",
  plot = woody_cover,
  width = 12,
  height = 5,
  dpi = 300
)

ggsave(
  "NebhutDukes2023_Fig5",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output/EPS",
  plot = woody_cover,
  width = 12,
  height = 5,
  device = cairo_ps
)

# W/ DBH
model_total_cover_woody_DBH <- lm(data = data_primary_species_no_SP_woody, total_cover ~ Plot * DBH * Location)
plot(model_total_cover_woody_DBH) # checking the homogeneity of variances
qqnorm(residuals(model_total_cover_woody_DBH)) # checking the normality of the residuals
summary(model_total_cover_woody_DBH) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_total_cover_woody_DBH) # provides the F, df, and P value for each independent factor
anova_stats(model_total_cover_woody_DBH) # provides the effect size (we are reporting Omega squared)

# **********************************************************************************************************
# DIVERSITY ANALYSIS: NATIVE TREE SPECIES ####
# **********************************************************************************************************
# Species richness
# W/o DBH
model_richness_native_trees <- lm(data = data_primary_species_native_trees, species_richness ~ Plot * Location)
plot(model_richness_native_trees) # checking the homogeneity of variances
qqnorm(residuals(model_richness_native_trees)) # checking the normality of the residuals
summary(model_richness_native_trees) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_richness_native_trees) # provides the F, df, and P value for each independent factor
anova_stats(model_richness_native_trees) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_richness_DBH_native_trees <- lm(data = data_primary_species_no_SP_native_trees, species_richness ~ Plot * DBH * Location)
plot(model_richness_DBH_native_trees) # checking the homogeneity of variances
qqnorm(residuals(model_richness_DBH_native_trees)) # checking the normality of the residuals
summary(model_richness_DBH_native_trees) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_richness_DBH_native_trees) # provides the F, df, and P value for each independent factor
anova_stats(model_richness_DBH_native_trees) # provides the effect size (we are reporting Omega squared)

# Shannon index analysis
# W/o DBH
model_shannon_native_trees <- lm(data = data_primary_species_native_trees, shannon_index ~ Plot * Location)
plot(model_shannon_native_trees) # checking the homogeneity of variances
qqnorm(residuals(model_shannon_native_trees)) # checking the normality of the residuals
summary(model_shannon_native_trees) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_shannon_native_trees) # provides the F, df, and P value for each independent factor
anova_stats(model_shannon_native_trees) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_shannon_DBH_native_trees <- lm(data = data_primary_species_no_SP_native_trees, shannon_index ~ Plot * DBH * Location)
plot(model_shannon_DBH_native_trees) # checking the homogeneity of variances
qqnorm(residuals(model_shannon_DBH_native_trees)) # checking the normality of the residuals
summary(model_shannon_DBH_native_trees) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_shannon_DBH_native_trees) # provides the F, df, and P value for each independent factor
anova_stats(model_shannon_DBH_native_trees) # provides the effect size (we are reporting Omega squared)

# Simpson index analysis
# W/o DBH
model_simpson_native_trees <- lm(data = data_primary_species_native_trees, simpson_index ~ Plot * Location)
plot(model_simpson_native_trees) # checking the homogeneity of variances
qqnorm(residuals(model_simpson_native_trees)) # checking the normality of the residuals
summary(model_simpson_native_trees) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_simpson_native_trees) # provides the F, df, and P value for each independent factor
anova_stats(model_simpson_native_trees) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_simpson_DBH_native_trees <- lm(data = data_primary_species_no_SP_native_trees, simpson_index ~ Plot * Location * DBH)
plot(model_simpson_DBH_native_trees) # checking the homogeneity of variances
qqnorm(residuals(model_simpson_DBH_native_trees)) # checking the normality of the residuals
summary(model_simpson_DBH_native_trees) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_simpson_DBH_native_trees) # provides the F, df, and P value for each independent factor
anova_stats(model_simpson_DBH_native_trees) # provides the effect size (we are reporting Omega squared)

# Total cover analysis
# W/o DBH
model_total_cover_native_trees <- lm(data = data_primary_species_native_trees, total_cover ~ Plot * Location)
plot(model_total_cover_native_trees) # checking the homogeneity of variances
qqnorm(residuals(model_total_cover_native_trees)) # checking the normality of the residuals
summary(model_total_cover_native_trees) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_total_cover_native_trees) # provides the F, df, and P value for each independent factor
anova_stats(model_total_cover_native_trees) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_total_cover_native_trees_DBH <- lm(data = data_primary_species_no_SP_native_trees, total_cover ~ Plot * DBH * Location)
plot(model_total_cover_native_trees_DBH) # checking the homogeneity of variances
qqnorm(residuals(model_total_cover_native_trees_DBH)) # checking the normality of the residuals
summary(model_total_cover_native_trees_DBH) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_total_cover_native_trees_DBH) # provides the F, df, and P value for each independent factor
anova_stats(model_total_cover_native_trees_DBH) # provides the effect size (we are reporting Omega squared)

# **********************************************************************************************************
# RELATIVE NATIVE VS. INTRODUCED ####
# **********************************************************************************************************
# create relative cover dataframe
# subset original dataframes with relevant columns
all_cover_df <- data_primary_species[, c("Plot_ID", "Plot", "Location", "DBH", "species_richness", "total_cover", "shannon_index", "simpson_index")]
invasive_cover_df <- data_primary_species_introduced[, c("Plot_ID", "Plot", "Location", "DBH", "species_richness", "total_cover", "shannon_index", "simpson_index")]

# join datasets
invasive_all_df <- join_all(list(all_cover_df, invasive_cover_df), by = c("Plot_ID", "Plot", "Location", "DBH"))

# rename columns
colnames(invasive_all_df) <- c(
  "PlotID", "Plot", "Location", "DBH",
  "all_richness", "all_cover", "all_shannon", "all_simpson",
  "introduced_richness", "introduced_cover", "introduced_shannon", "introduced_simpson"
)

# calculate relative richness, cover, shannon index, and simpson index
invasive_all_df <- mutate(invasive_all_df, relative_richness = (introduced_richness / all_richness))
invasive_all_df <- mutate(invasive_all_df, relative_cover = (introduced_cover / all_cover))
invasive_all_df <- mutate(invasive_all_df, relative_shannon = (introduced_shannon / all_shannon))
invasive_all_df <- mutate(invasive_all_df, relative_simpson = (introduced_simpson / all_simpson))

# remove SP rows for DBH analysis
invasive_all_df_no_SP <- invasive_all_df[invasive_all_df$Plot %in% c("LITU", "PYCA80", "PLOC"), ]

# Species richness analysis
# W/o DBH
model_richness_relative <- lm(data = invasive_all_df, relative_richness ~ Plot * Location)
plot(model_richness_relative) # checking the homogeneity of variances
qqnorm(residuals(model_richness_relative)) # checking the normality of the residuals
summary(model_richness_relative) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_richness_relative) # provides the F, df, and P value for each independent factor
anova_stats(model_richness_relative) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_richness_DBH_relative <- lm(data = invasive_all_df_no_SP, relative_richness ~ Plot * DBH * Location)
plot(model_richness_DBH_relative) # checking the homogeneity of variances
qqnorm(residuals(model_richness_DBH_relative)) # checking the normality of the residuals
summary(model_richness_DBH_relative) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_richness_DBH_relative) # provides the F, df, and P value for each independent factor
anova_stats(model_richness_DBH_relative) # provides the effect size (we are reporting Omega squared)

# Shannon index analysis
# W/o DBH
model_shannon_relative <- lm(data = invasive_all_df, relative_shannon ~ Plot * Location)
plot(model_shannon_relative) # checking the homogeneity of variances
qqnorm(residuals(model_shannon_relative)) # checking the normality of the residuals
summary(model_shannon_relative) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_shannon_relative) # provides the F, df, and P value for each independent factor
anova_stats(model_shannon_relative) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_shannon_DBH_relative <- lm(data = invasive_all_df_no_SP, relative_shannon ~ Plot * DBH * Location)
plot(model_shannon_DBH_relative) # checking the homogeneity of variances
qqnorm(residuals(model_shannon_DBH_relative)) # checking the normality of the residuals
summary(model_shannon_DBH_relative) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_shannon_DBH_relative) # provides the F, df, and P value for each independent factor
anova_stats(model_shannon_DBH_relative) # provides the effect size (we are reporting Omega squared)

# Simpson index analysis
# W/o DBH
model_simpson_relative <- lm(data = invasive_all_df, relative_simpson ~ Plot * Location)
plot(model_simpson_relative) # checking the homogeneity of variances
qqnorm(residuals(model_simpson_relative)) # checking the normality of the residuals
summary(model_simpson_relative) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_simpson_relative) # provides the F, df, and P value for each independent factor
anova_stats(model_simpson_relative) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_simpson_DBH_relative <- lm(data = invasive_all_df_no_SP, relative_simpson ~ Plot * Location * DBH)
plot(model_simpson_DBH_relative) # checking the homogeneity of variances
qqnorm(residuals(model_simpson_DBH_relative)) # checking the normality of the residuals
summary(model_simpson_DBH_relative) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_simpson_DBH_relative) # provides the F, df, and P value for each independent factor
anova_stats(model_simpson_DBH_relative) # provides the effect size (we are reporting Omega squared)

# Total cover analysis
# W/o DBH
model_total_cover_relative <- lm(data = invasive_all_df, relative_cover ~ Plot * Location)
plot(model_total_cover_relative) # checking the homogeneity of variances
qqnorm(residuals(model_total_cover_relative)) # checking the normality of the residuals
summary(model_total_cover_relative) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_total_cover_relative) # provides the F, df, and P value for each independent factor
anova_stats(model_total_cover_relative) # provides the effect size (we are reporting Omega squared)

# W/ DBH
model_total_cover_relative_DBH <- lm(data = invasive_all_df_no_SP, relative_cover ~ Plot * DBH * Location)
plot(model_total_cover_relative_DBH) # checking the homogeneity of variances
qqnorm(residuals(model_total_cover_relative_DBH)) # checking the normality of the residuals
summary(model_total_cover_relative_DBH) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(model_total_cover_relative_DBH) # provides the F, df, and P value for each independent factor
anova_stats(model_total_cover_relative_DBH) # provides the effect size (we are reporting Omega squared)

# **********************************************************************************************************
# DBH GRAPHS ####
# **********************************************************************************************************
# Set up labels
levels(data_primary_species$Plot) <- c(
  `LITU` = expression(paste(italic("L. tulipifera"))),
  `PLOC` = expression(paste(italic("P. occidentalis"))),
  `PYCA80` = expression(paste(italic("P. calleryana"))),
  `SP` = expression(paste("Control"))
)

# Convert DBH to cm
data_primary_species$DBH_cm <- data_primary_species$DBH * 2.54

# Species richness (S)
dbh_rich <- ggplot(data = data_primary_species, aes(x = DBH_cm, y = species_richness)) +
  geom_point(aes(color = Plot, shape = Location), size = 3) +
  theme_classic(base_size = 18) +
  theme(legend.text = element_markdown()) +
  xlab("DBH (cm)") +
  ylab("Species richness (S)") +
  facet_grid(Plot ~ .,
    labeller = label_parsed
  ) +
  scale_color_manual(
    values = c("#7AD151", "#FDE725", "#22A384", "#2A788E"),
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  )

# Total cover (%)
dbh_totalcvr <- ggplot(data = data_primary_species, aes(x = DBH_cm, y = total_cover)) +
  geom_point(aes(color = Plot, shape = Location), size = 3) +
  theme_classic(base_size = 18) +
  xlab("DBH (cm)") +
  ylab("Total Cover (%)") +
  facet_grid(Plot ~ .,
    labeller = label_parsed
  ) +
  scale_color_manual(
    values = c("#7AD151", "#FDE725", "#22A384", "#2A788E"),
    name = "Plot Type",
    labels = c("L. tulipifera", "P. occidentalis", "P. calleryana", "Control")
  )

# Shannon index (H)
dbh_shannon <- ggplot(data = data_primary_species, aes(x = DBH_cm, y = shannon_index)) +
  geom_point(aes(color = Plot, shape = Location), size = 3) +
  theme_classic(base_size = 18) +
  xlab("DBH (cm)") +
  ylab("Shannon index (H)") +
  facet_grid(Plot ~ .,
    labeller = label_parsed
  ) +
  scale_color_manual(
    values = c("#7AD151", "#FDE725", "#22A384", "#2A788E"),
    name = "Plot Type",
    labels = c("L. tulipifera", "P. occidentalis", "P. calleryana", "Control")
  )

# Simpson index (D)
dbh_simpson <- ggplot(data = data_primary_species, aes(x = DBH_cm, y = simpson_index)) +
  geom_point(aes(color = Plot, shape = Location), size = 3) +
  theme_classic(base_size = 18) +
  xlab("DBH (cm)") +
  ylab("Simpson index (D)") +
  facet_grid(Plot ~ .,
    labeller = label_parsed
  ) +
  scale_color_manual(
    values = c("#7AD151", "#FDE725", "#22A384", "#2A788E"),
    name = "Plot Type",
    labels = c("L. tulipifera", "P. occidentalis", "P. calleryana", "Control")
  )

dbh_graphs <- ggarrange(dbh_rich, dbh_totalcvr, dbh_shannon, dbh_simpson,
  labels = "AUTO",
  ncol = 4, nrow = 1, font.label = list(size = 14),
  hjust = -0.5, vjust = 1.5,
  align = c("h"),
  legend = "bottom",
  common.legend = TRUE
)

ggsave(
  "dbh_graphs.png",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output",
  plot = dbh_graphs,
  width = 18,
  height = 8,
  dpi = 300
)

ggsave(
  "NebhutDukes2023_FigS1",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output/EPS",
  plot = dbh_graphs,
  width = 18,
  height = 8,
  device = cairo_ps
)

# **********************************************************************************************************
# NUMBER OF SPECIES PER SITE IN EACH COMMUNITY SUBSET ####
# **********************************************************************************************************
# all species
data_species <- aggregate(data_primary_species[, c(5:136)], by = list(data_primary_species$Location), FUN = "sum")
data_species <- setNames(data.frame(t(data_species[, -1])), data_species[, 1])
data_species$ALL <- rowSums(data_species)
data_species[data_species > 0] <- 1
colSums(data_species)

# introduced species
data_introduced_species <- aggregate(data_primary_species_introduced[, c(5:41)], by = list(data_primary_species_introduced$Location), FUN = "sum")
data_introduced_species <- setNames(data.frame(t(data_introduced_species[, -1])), data_introduced_species[, 1])
data_introduced_species$ALL <- rowSums(data_introduced_species)
data_introduced_species[data_introduced_species > 0] <- 1
colSums(data_introduced_species)

# native species
data_native_species <- aggregate(data_primary_species_native[, c(5:99)], by = list(data_primary_species_native$Location), FUN = "sum")
data_native_species <- setNames(data.frame(t(data_native_species[, -1])), data_native_species[, 1])
data_native_species$ALL <- rowSums(data_native_species)
data_native_species[data_native_species > 0] <- 1
colSums(data_native_species)

# woody species
data_woody_species <- aggregate(data_primary_species_woody[, c(5:37)], by = list(data_primary_species_woody$Location), FUN = "sum")
data_woody_species <- setNames(data.frame(t(data_woody_species[, -1])), data_woody_species[, 1])
data_woody_species$ALL <- rowSums(data_woody_species)
data_woody_species[data_woody_species > 0] <- 1
colSums(data_woody_species)

# native tree species
data_native_tree_species <- aggregate(data_primary_species_native_trees[, c(5:26)], by = list(data_primary_species_native_trees$Location), FUN = "sum")
data_native_tree_species <- setNames(data.frame(t(data_native_tree_species[, -1])), data_native_tree_species[, 1])
data_native_tree_species$ALL <- rowSums(data_native_tree_species)
data_native_tree_species[data_native_tree_species > 0] <- 1
colSums(data_native_tree_species)


# **********************************************************************************************************
# BASAL AREA OF THE TREES ####
# **********************************************************************************************************
# calculate the basal area of each tree from its DBH
data_primary_species_no_SP$basal_area_cm2 <- pi * (data_primary_species_no_SP$DBH_cm / 2)^2

# calculate the percentage of the sampling plot (1 m2 = 10,000 cm2) taken up by the tree
data_primary_species_no_SP$percent_basal_area <- data_primary_species_no_SP$basal_area_cm2 / (10000) * 100

# calculate descriptive statistics
summary(data_primary_species_no_SP$percent_basal_area)
se(data_primary_species_no_SP$percent_basal_area)

# **********************************************************************************************************
# SINGLE-LOCATION ANALYSIS ####
# **********************************************************************************************************

# Correct level names of data_primary_species
levels(data_primary_species$Plot) <- c(
  `paste(italic("L. tulipifera"))` = "LITU",
  `paste(italic("P. occidentalis"))` = "PLOC",
  `paste(italic("P. calleryana"))` = "PYCA80",
  `paste(italic("Control"))` = "SP"
)

# Assign all SPs a DBH of NA, not 0
data_primary_species$DBH <- ifelse(data_primary_species$Plot == "SP",
  NA,
  data_primary_species$DBH
)

data_primary_species_introduced$DBH <- ifelse(data_primary_species_introduced$Plot == "SP",
  NA,
  data_primary_species_introduced$DBH
)

data_primary_species_native$DBH <- ifelse(data_primary_species_native$Plot == "SP",
  NA,
  data_primary_species_native$DBH
)

data_primary_species_woody$DBH <- ifelse(data_primary_species_woody$Plot == "SP",
  NA,
  data_primary_species_woody$DBH
)

data_primary_species_native_trees$DBH <- ifelse(data_primary_species_native_trees$Plot == "SP",
  NA,
  data_primary_species_native_trees$DBH
)

# calculate DBH_cm for the dataframes that were missing them
data_primary_species$DBH_cm <- data_primary_species$DBH * 2.54
data_primary_species_introduced$DBH_cm <- data_primary_species_introduced$DBH * 2.54
data_primary_species_native$DBH_cm <- data_primary_species_native$DBH * 2.54
data_primary_species_woody$DBH_cm <- data_primary_species_woody$DBH * 2.54
data_primary_species_native_trees$DBH_cm <- data_primary_species_native_trees$DBH * 2.54

# list all community subset frames, with and without control sampling points
list_dataframes <- list(
  "data_primary_species" = data_primary_species,
  "data_primary_species_native" = data_primary_species_native,
  "data_primary_species_introduced" = data_primary_species_introduced,
  "data_primary_species_woody" = data_primary_species_woody,
  "data_primary_species_native_trees" = data_primary_species_native_trees
)

# # check that DBH_cm exists in each dataframe now
# for(df in list_dataframes){
#   if("DBH_cm" %in% names(df)){
#     print("true")
#   }
# }

# define a function that selects the overall p value from a linear model
overall_p <- function(my_model) {
  f <- summary(my_model)$fstatistic
  p <- pf(f[1], f[2], f[3], lower.tail = F)
  attributes(p) <- NULL
  return(p)
}

## Save a dataframe as a csv file to a specified directory
# the filename is : dataframeName_{user input string}.csv or dataframeName.csv if there's no tag provided
saveDFcsv <- function(inputDF, tag = NULL, od = outputDir) {
  # check if od ends with /, add if not
  if (substr(od, nchar(od), nchar(od)) != "/") {
    od <- paste0(od, "/")
  }

  # note that this doesn't work with a list of data frames
  dfName <- substitute(inputDF)
  if (is.null(tag)) {
    outputPath <- paste0(od, dfName, ".csv")
  } else {
    outputPath <- paste0(od, dfName, "_", tag, ".csv")
  }
  print(outputPath)
  write.csv(inputDF, outputPath)
}

list_locations <- c("BWNP", "CRAW", "SRNP")

# the define model names and their equations,
# the names here are used for naming columns, and affects the order of columns in the output csv
# non-DBH and DBH models are grouped by the lm variable
lm_models <- c(
  "richness" = "species_richness ~ Plot",
  "richness_dbh" = "species_richness ~ Plot * DBH_cm",
  "totcov" = "total_cover ~ Plot",
  "totcov_dbh" = "total_cover ~ Plot * DBH_cm",
  "shannon" = "shannon_index ~ Plot",
  "shannon_dbh" = "shannon_index ~ Plot * DBH_cm",
  "simpson" = "simpson_index ~ Plot",
  "simpson_dbh" = "simpson_index ~ Plot * DBH_cm"
)

# non dbh and dbh models grouped separately
# lm_models <- c(
#   "totcov" = "total_cover ~ Plot",
#   "richness" = "species_richness ~ Plot",
#   "shannon" = "shannon_index ~ Plot",
#   "simpson" = "simpson_index ~ Plot",
#   "totcov_dbh" = "total_cover ~ Plot * DBH_cm",
#   "richness_dbh" = "species_richness ~ Plot * DBH_cm",
#   "shannon_dbh" = "shannon_index ~ Plot * DBH_cm",
#   "simpson_dbh" = "simpson_index ~ Plot * DBH_cm"
# )

# create the output structure: a list of lists of lists of dataframes?
# each location will be processed
output <- vector(mode = "list", length = length(list_locations))

names(output) <- list_locations

for (loc in list_locations) {
  # each location will be processed for each data frame
  output[[loc]] <- vector("list", length(list_dataframes))
  names(output[[loc]]) <- names(list_dataframes)

  for (i in 1:length(list_dataframes)) {
    # each data frame will be processed for each model
    output[[loc]][[names(list_dataframes[i])]] <- vector("list", length(lm_models))
    names(output[[loc]][[names(list_dataframes[i])]]) <- names(lm_models)
  }
}

# print(str(output)) # debug message

# populate the structure with the relevant data
# for each location
for (loc in list_locations) {
  # print(loc) # debug message

  # for each dataframe
  for (i in 1:length(list_dataframes)) {
    # print( names(list_dataframes[i]) ) # debug message

    # select only plots in the relevant location
    loc_df <- list_dataframes[[i]][list_dataframes[[i]]$Location == loc, ]

    # for each model
    for (j in 1:length(lm_models)) {
      # print( names(lm_models[j]) ) # debug message

      # create column names based on the model being run
      prefix <- paste0("sum_lm_", names(lm_models[j]))
      # print(prefix)
      output_cols <- c(
        paste0(prefix, "_fstat"),
        # paste0(prefix, "_numdf"),
        # paste0(prefix, "_denomdf"),
        paste0(prefix, "_pval"), # this can't be a clean loop cause anova function :C
        paste0(prefix, "_r2")
      )
      # print(output_cols) # debug message

      # run model
      lm_temp <- lm(data = loc_df, as.formula(lm_models[j]))

      # calculate the statistics and arrange into a data frame
      # summary of lm has fstatistics and adj.r.squared
      sum_lm_temp <- summary(lm_temp)

      temp_lm_stats_df <- data.frame(
        round(sum_lm_temp$fstatistic[1], digits = 3),
        # sum_lm_temp$fstatistic[2],
        # sum_lm_temp$fstatistic[3],
        round(overall_p(lm_temp), digits = 2),
        round(sum_lm_temp$adj.r.squared[1], digits = 2)
      )
      names(temp_lm_stats_df) <- output_cols # apply column names

      # store in structure
      output[[loc]][[names(list_dataframes[i])]][[names(lm_models[j])]] <- temp_lm_stats_df
    }
  }
}

str(output) # debug message

# create a single table for each location and save to csv
# lm_models need to be cbind, horizontal
# list_dataframes need to be rbind, vertical
output_dfs <- vector("list", length(list_locations))
for (loc in list_locations) {
  # print(loc) # debug message

  # structure to hold each row
  rows <- vector("list", length = length(list_dataframes))
  for (i in 1:length(list_dataframes)) {
    # print(names(list_dataframes[i])) # debug message

    # build one row
    rows[[i]] <- data.frame(do.call(cbind, output[[loc]][[names(list_dataframes[i])]]),
      row.names = names(list_dataframes[i])
    )

    # print(df_temp) # debug message
  }
  # put all the rows together
  site <- data.frame(do.call(rbind, rows))

  # save that output to a csv
  saveDFcsv(site, tag = loc)
}

# The statistically significant models include:
# CRAW all richness w/o DBH
# CRAW all Shannon w/o DBH
# CRAW native richness w/o DBH
# SRNP woody total cover w/o DBH

# SRNP total cover w/ DBH
# CRAW native richness w/ DBH
# CRAW native Shannon w/ DBH
# CRAW woody Simpson w/ DBH

# Define relevant single-location datasets
CRAW_data_primary_species <- data_primary_species[data_primary_species$Location == "CRAW", ]
SRNP_data_primary_species <- data_primary_species[data_primary_species$Location == "SRNP", ]
CRAW_data_primary_species_native <- data_primary_species_native[data_primary_species_native$Location == "CRAW", ]
CRAW_data_primary_species_woody <- data_primary_species_woody[data_primary_species_woody$Location == "CRAW", ]
SRNP_data_primary_species_woody <- data_primary_species_woody[data_primary_species_woody$Location == "SRNP", ]

# Investigate non-DBH models
# CRAW all richness w/o DBH: plot significant SP vs. LITU significant, nothing else
CRAW_model_richness_all <- lm(data = CRAW_data_primary_species, species_richness ~ Plot)
plot(CRAW_model_richness_all) # checking the homogeneity of variances
qqnorm(residuals(CRAW_model_richness_all)) # checking the normality of the residuals
summary(CRAW_model_richness_all) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(CRAW_model_richness_all) # provides the F, df, and P value for each independent factor
anova_stats(CRAW_model_richness_all) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = CRAW_data_primary_species, species_richness ~ Plot))

CRAW_richness_all_means <- data.frame(aggregate(data = CRAW_data_primary_species, species_richness ~ Plot, FUN = mean))
CRAW_richness_all_se <- data.frame(aggregate(data = CRAW_data_primary_species, species_richness ~ Plot, FUN = se))
CRAW_richness_all_stats <- join_all(list(CRAW_richness_all_means, CRAW_richness_all_se), by = c("Plot"))
colnames(CRAW_richness_all_stats) <- c("Plot", "Mean", "se")

anova_CRAW_richness_all_plot <- aov(data = CRAW_data_primary_species, species_richness ~ Plot)
tukey_CRAW_richness_all_plot <- TukeyHSD(anova_CRAW_richness_all_plot)
cld_CRAW_richness_all_plot <- multcompLetters4(anova_CRAW_richness_all_plot, tukey_CRAW_richness_all_plot)
cld_CRAW_richness_all_plot <- as.data.frame.list(cld_CRAW_richness_all_plot$Plot)
cld_CRAW_richness_all_plot <- cld_CRAW_richness_all_plot[sort(row.names(cld_CRAW_richness_all_plot)), ]

CRAW_richness_all_plot <- ggplot(data = CRAW_richness_all_stats, aes(x = Plot, y = Mean)) +
  geom_point(
    data = CRAW_data_primary_species, aes(
      x = Plot, y = species_richness,
      color = Plot, shape = Location
    ),
    position = position_jitter(w = 0.2, h = 0),
    size = 3,
    # shape = "triangle"
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Plot Type") +
  ylab("CRAW\nSpecies Richness (S)") +
  geom_text(aes(label = cld_CRAW_richness_all_plot$Letters),
    y = 11,
    size = 5
  ) +
  scale_x_discrete(labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")) +
  theme(
    axis.text.x = element_markdown(),
    legend.text = element_markdown()
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  ) +
  scale_shape_manual(
    labels = c("BWNP", "CRAW", "SRNP"),
    values = c("circle", "triangle", "square"),
    drop = FALSE
  )
# guides(
#   color = guide_legend(order = 1),
#   shape = guide_legend(order = 2)
# )


# CRAW all Shannon w/o DBH: SP vs. LITU significant, nothing else
CRAW_model_shannon_all <- lm(data = CRAW_data_primary_species, shannon_index ~ Plot)
plot(CRAW_model_shannon_all) # checking the homogeneity of variances
qqnorm(residuals(CRAW_model_shannon_all)) # checking the normality of the residuals
summary(CRAW_model_shannon_all) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(CRAW_model_shannon_all) # provides the F, df, and P value for each independent factor
anova_stats(CRAW_model_shannon_all) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = CRAW_data_primary_species, shannon_index ~ Plot))

CRAW_shannon_all_means <- data.frame(aggregate(data = CRAW_data_primary_species, shannon_index ~ Plot, FUN = mean))
CRAW_shannon_all_se <- data.frame(aggregate(data = CRAW_data_primary_species, shannon_index ~ Plot, FUN = se))
CRAW_shannon_all_stats <- join_all(list(CRAW_shannon_all_means, CRAW_shannon_all_se), by = c("Plot"))
colnames(CRAW_shannon_all_stats) <- c("Plot", "Mean", "se")

anova_CRAW_shannon_all_plot <- aov(data = CRAW_data_primary_species, shannon_index ~ Plot)
tukey_CRAW_shannon_all_plot <- TukeyHSD(anova_CRAW_shannon_all_plot)
cld_CRAW_shannon_all_plot <- multcompLetters4(anova_CRAW_shannon_all_plot, tukey_CRAW_shannon_all_plot)
cld_CRAW_shannon_all_plot <- as.data.frame.list(cld_CRAW_shannon_all_plot$Plot)
cld_CRAW_shannon_all_plot <- cld_CRAW_shannon_all_plot[sort(row.names(cld_CRAW_shannon_all_plot)), ]

CRAW_shannon_all_plot <- ggplot(data = CRAW_shannon_all_stats, aes(x = Plot, y = Mean)) +
  geom_point(
    data = CRAW_data_primary_species, aes(
      x = Plot, y = shannon_index,
      color = Plot
    ),
    position = position_jitter(w = 0.2, h = 0),
    size = 3,
    shape = "triangle"
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Plot Type") +
  ylab("CRAW\nShannon Index (H)") +
  geom_text(aes(label = cld_CRAW_shannon_all_plot$Letters),
    y = 1.9,
    size = 5
  ) +
  scale_x_discrete(labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")) +
  theme(
    axis.text.x = element_markdown(),
    legend.text = element_markdown()
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )

# CRAW native richness w/o DBH: plot significant SP vs. LITU significant, nothing else
CRAW_model_richness_native <- lm(data = CRAW_data_primary_species_native, species_richness ~ Plot)
plot(CRAW_model_richness_native) # checking the homogeneity of variances
qqnorm(residuals(CRAW_model_richness_native)) # checking the normality of the residuals
summary(CRAW_model_richness_native) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(CRAW_model_richness_native) # provides the F, df, and P value for each independent factor
anova_stats(CRAW_model_richness_native) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = CRAW_data_primary_species_native, species_richness ~ Plot))

CRAW_richness_native_means <- data.frame(aggregate(data = CRAW_data_primary_species_native, species_richness ~ Plot, FUN = mean))
CRAW_richness_native_se <- data.frame(aggregate(data = CRAW_data_primary_species_native, species_richness ~ Plot, FUN = se))
CRAW_richness_native_stats <- join_all(list(CRAW_richness_native_means, CRAW_richness_native_se), by = c("Plot"))
colnames(CRAW_richness_native_stats) <- c("Plot", "Mean", "se")

anova_CRAW_richness_native_plot <- aov(data = CRAW_data_primary_species_native, species_richness ~ Plot)
tukey_CRAW_richness_native_plot <- TukeyHSD(anova_CRAW_richness_native_plot)
cld_CRAW_richness_native_plot <- multcompLetters4(anova_CRAW_richness_native_plot, tukey_CRAW_richness_native_plot)
cld_CRAW_richness_native_plot <- as.data.frame.list(cld_CRAW_richness_native_plot$Plot)
cld_CRAW_richness_native_plot <- cld_CRAW_richness_native_plot[sort(row.names(cld_CRAW_richness_native_plot)), ]

CRAW_richness_native_plot <- ggplot(data = CRAW_richness_native_stats, aes(x = Plot, y = Mean)) +
  geom_point(
    data = CRAW_data_primary_species_native, aes(
      x = Plot, y = species_richness,
      color = Plot
    ),
    position = position_jitter(w = 0.2, h = 0),
    size = 3,
    shape = "triangle"
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Plot Type") +
  ylab("CRAW Native\nSpecies Richness (S)") +
  geom_text(aes(label = cld_CRAW_richness_native_plot$Letters),
    y = 9,
    size = 5
  ) +
  scale_x_discrete(labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")) +
  theme(
    axis.text.x = element_markdown(),
    legend.text = element_markdown()
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )

# SRNP woody total cover w/o DBH: plot significant, no significant pairwise comparisons
SRNP_model_totalcover_woody <- lm(data = SRNP_data_primary_species_woody, total_cover ~ Plot)
plot(SRNP_model_totalcover_woody) # checking the homogeneity of variances
qqnorm(residuals(SRNP_model_totalcover_woody)) # checking the normality of the residuals
summary(SRNP_model_totalcover_woody) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(SRNP_model_totalcover_woody) # provides the F, df, and P value for each independent factor
anova_stats(SRNP_model_totalcover_woody) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = SRNP_data_primary_species_woody, total_cover ~ Plot))

SRNP_totalcover_woody_means <- data.frame(aggregate(data = SRNP_data_primary_species_woody, total_cover ~ Plot, FUN = mean))
SRNP_totalcover_woody_se <- data.frame(aggregate(data = SRNP_data_primary_species_woody, total_cover ~ Plot, FUN = se))
SRNP_totalcover_woody_stats <- join_all(list(SRNP_totalcover_woody_means, SRNP_totalcover_woody_se), by = c("Plot"))
colnames(SRNP_totalcover_woody_stats) <- c("Plot", "Mean", "se")

anova_SRNP_totalcover_native_plot <- aov(data = SRNP_data_primary_species_woody, total_cover ~ Plot)
tukey_SRNP_totalcover_native_plot <- TukeyHSD(anova_SRNP_totalcover_native_plot)
cld_SRNP_totalcover_native_plot <- multcompLetters4(anova_SRNP_totalcover_native_plot, tukey_SRNP_totalcover_native_plot)
cld_SRNP_totalcover_native_plot <- as.data.frame.list(cld_SRNP_totalcover_native_plot$Plot)
cld_SRNP_totalcover_native_plot <- cld_SRNP_totalcover_native_plot[sort(row.names(cld_SRNP_totalcover_native_plot)), ]

SRNP_totalcover_native_plot <- ggplot(data = SRNP_totalcover_woody_stats, aes(x = Plot, y = Mean)) +
  geom_point(
    data = SRNP_data_primary_species_woody, aes(
      x = Plot, y = total_cover,
      color = Plot
    ),
    position = position_jitter(w = 0.2, h = 0),
    size = 3,
    shape = "square"
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Plot Type") +
  ylab("SRNP Woody\nTotal Cover (%)") +
  geom_text(aes(label = cld_SRNP_totalcover_native_plot$Letters),
    y = 120,
    size = 5
  ) +
  scale_x_discrete(labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")) +
  theme(
    axis.text.x = element_markdown(),
    legend.text = element_markdown()
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*", "Control")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )

# Combine graphs
plot_analysis_woDBH <- ggarrange(CRAW_richness_all_plot, CRAW_shannon_all_plot,
  CRAW_richness_native_plot, SRNP_totalcover_native_plot,
  ncol = 2, nrow = 2,
  hjust = -0.5, vjust = 1.5,
  legend = "bottom",
  common.legend = TRUE,
  labels = "AUTO"
)

ggsave(
  "plot_analysis_woDBH.png",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output",
  plot = plot_analysis_woDBH,
  width = 13,
  height = 8,
  dpi = 300
)

ggsave(
  "NebhutDukes2023_FigS6",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/ReviewerResponseSubmission/EPS",
  plot = plot_analysis_woDBH,
  width = 13,
  height = 8,
  device = cairo_ps
)

# Investigate w/ DBH models
# SRNP total cover w/ DBH
# CRAW native richness w/ DBH
# CRAW native Shannon w/ DBH
# CRAW woody Simpson w/ DBH

# SRNP total cover w/ DBH: DBH significant
SRNP_model_totalcov_all_DBH <- lm(data = SRNP_data_primary_species, total_cover ~ Plot * DBH_cm)
plot(SRNP_model_totalcov_all_DBH) # checking the homogeneity of variances
qqnorm(residuals(SRNP_model_totalcov_all_DBH)) # checking the normality of the residuals
summary(SRNP_model_totalcov_all_DBH) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(SRNP_model_totalcov_all_DBH) # provides the F, df, and P value for each independent factor
anova_stats(SRNP_model_totalcov_all_DBH) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = SRNP_data_primary_species, total_cover ~ Plot * DBH_cm))


SRNP_totalcov_woody_DBH <- ggplot(data = SRNP_data_primary_species, aes(x = DBH_cm, y = total_cover)) +
  geom_point(aes(color = Plot),
    position = position_jitter(w = 0.2, h = 0),
    size = 3, shape = "square"
  ) +
  geom_smooth(method = "lm", se = TRUE, color = "black") +
  theme_classic(base_size = 18) +
  theme(
    legend.text = element_markdown()
  ) +
  xlab("DBH (cm)") +
  ylab("SRNP Total Cover (%)") +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette[1:3],
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*")
  )
  # scale_shape_manual(
  #   labels = c("BWNP", "CRAW", "SRNP"),
  #   values = c("circle", "triangle", "square"),
  #   drop = FALSE
  # )

# CRAW native richness w/ DBH: plot significant, w/ SP vs. LITU and PITU vs. PLOC significant, nothing else
CRAW_model_richness_native_DBH <- lm(data = CRAW_data_primary_species_native, species_richness ~ Plot * DBH_cm)
plot(CRAW_model_richness_native_DBH) # checking the homogeneity of variances
qqnorm(residuals(CRAW_model_richness_native_DBH)) # checking the normality of the residuals
summary(CRAW_model_richness_native_DBH) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(CRAW_model_richness_native_DBH) # provides the F, df, and P value for each independent factor
anova_stats(CRAW_model_richness_native_DBH) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = CRAW_data_primary_species_native, species_richness ~ Plot * DBH_cm))

CRAW_richness_native_means <- data.frame(aggregate(data = CRAW_data_primary_species_native, species_richness ~ Plot, FUN = mean))
CRAW_richness_native_se <- data.frame(aggregate(data = CRAW_data_primary_species_native, species_richness ~ Plot, FUN = se))
CRAW_richness_native_stats <- join_all(list(CRAW_richness_native_means, CRAW_richness_native_se), by = c("Plot"))
colnames(CRAW_richness_native_stats) <- c("Plot", "Mean", "se")

anova_CRAW_richness_native_plot <- aov(data = CRAW_data_primary_species_native, species_richness ~ Plot * DBH_cm)
tukey_CRAW_richness_native_plot <- TukeyHSD(anova_CRAW_richness_native_plot)
cld_CRAW_richness_native_plot <- multcompLetters4_fixed_2(anova_CRAW_richness_native_plot, tukey_CRAW_richness_native_plot)
cld_CRAW_richness_native_plot <- as.data.frame.list(cld_CRAW_richness_native_plot$Plot)
cld_CRAW_richness_native_plot <- cld_CRAW_richness_native_plot[sort(row.names(cld_CRAW_richness_native_plot)), ]

CRAW_richness_native_plot <- ggplot(data = CRAW_richness_native_stats[1:3, ], aes(x = Plot, y = Mean)) +
  geom_point(
    data = CRAW_data_primary_species_native[1:30, ], aes(
      x = Plot, y = species_richness,
      color = Plot, shape = Location
    ),
    position = position_jitter(w = 0.2, h = 0),
    size = 3,
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Plot Type") +
  ylab("CRAW Native\nSpecies Richness (S)") +
  geom_text(aes(label = cld_CRAW_richness_native_plot$Letters),
    y = 8.5,
    size = 5
  ) +
  scale_x_discrete(labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*")) +
  theme(
    axis.text.x = element_markdown(),
    legend.text = element_markdown()
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*")
  ) +
  scale_shape_manual(
    labels = c("BWNP", "CRAW", "SRNP"),
    values = c("circle", "triangle", "square"),
    drop = FALSE
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2))

# CRAW native Shannon w/ DBH: plot significant, but no differences among pairwise comparisons
CRAW_model_shannon_native_DBH <- lm(data = CRAW_data_primary_species_native, shannon_index ~ Plot * DBH_cm)
plot(CRAW_model_shannon_native_DBH) # checking the homogeneity of variances
qqnorm(residuals(CRAW_model_shannon_native_DBH)) # checking the normality of the residuals
summary(CRAW_model_shannon_native_DBH) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(CRAW_model_shannon_native_DBH) # provides the F, df, and P value for each independent factor
anova_stats(CRAW_model_shannon_native_DBH) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = CRAW_data_primary_species_native, shannon_index ~ Plot * DBH_cm))

CRAW_shannon_native_means <- data.frame(aggregate(data = CRAW_data_primary_species_native, shannon_index ~ Plot, FUN = mean))
CRAW_shannon_native_se <- data.frame(aggregate(data = CRAW_data_primary_species_native, shannon_index ~ Plot, FUN = se))
CRAW_shannon_native_stats <- join_all(list(CRAW_shannon_native_means, CRAW_shannon_native_se), by = c("Plot"))
colnames(CRAW_shannon_native_stats) <- c("Plot", "Mean", "se")

anova_CRAW_shannon_native_plot <- aov(data = CRAW_data_primary_species_native, shannon_index ~ Plot * DBH_cm)
tukey_CRAW_shannon_native_plot <- TukeyHSD(anova_CRAW_shannon_native_plot)
cld_CRAW_shannon_native_plot <- multcompLetters4_fixed_2(anova_CRAW_shannon_native_plot, tukey_CRAW_shannon_native_plot)
cld_CRAW_shannon_native_plot <- as.data.frame.list(cld_CRAW_shannon_native_plot$Plot)
cld_CRAW_shannon_native_plot <- cld_CRAW_shannon_native_plot[sort(row.names(cld_CRAW_shannon_native_plot)), ]

CRAW_shannon_native_plot <- ggplot(data = CRAW_shannon_native_stats[1:3, ], aes(x = Plot, y = Mean)) +
  geom_point(
    data = CRAW_data_primary_species_native[1:30, ], aes(
      x = Plot, y = shannon_index,
      color = Plot
    ),
    position = position_jitter(w = 0.2, h = 0),
    size = 3,
    shape = "triangle"
  ) +
  geom_point(size = 3, position = position_dodge(width = 0.3)) +
  geom_errorbar(aes(ymin = Mean - se, ymax = Mean + se), width = 0.2, size = 1, position = position_dodge(width = 0.3)) +
  theme_classic(base_size = 18) +
  xlab("Plot Type") +
  ylab("CRAW Native\nShannon Index (H)") +
  geom_text(aes(label = cld_CRAW_shannon_native_plot$Letters),
    y = 1.75,
    size = 5
  ) +
  scale_x_discrete(labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*")) +
  theme(
    axis.text.x = element_markdown(),
    legend.text = element_markdown()
  ) +
  theme(plot.margin = grid::unit(c(0, 0, 0, 0), "mm")) +
  scale_color_manual(
    values = color_palette,
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*")
  ) +
  guides(
    color = guide_legend(order = 1),
    shape = guide_legend(order = 2)
  )

# CRAW woody Simpson w/ DBH: plot*DBH significant
CRAW_model_simpson_woody_DBH <- lm(data = CRAW_data_primary_species_woody, simpson_index ~ Plot * DBH_cm)
plot(CRAW_model_simpson_woody_DBH) # checking the homogeneity of variances
qqnorm(residuals(CRAW_model_simpson_woody_DBH)) # checking the normality of the residuals
summary(CRAW_model_simpson_woody_DBH) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(CRAW_model_simpson_woody_DBH) # provides the F, df, and P value for each independent factor
anova_stats(CRAW_model_simpson_woody_DBH) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = CRAW_data_primary_species_woody, simpson_index ~ Plot * DBH_cm))
posthoc_Trends_Pairwise(CRAW_model_simpson_woody_DBH, "Plot", "DBH_cm", P_Adj = "bonferroni")

CRAW_simpson_woody_DBH_all <- ggplot(data = CRAW_data_primary_species_woody[1:30, ], aes(x = DBH_cm, y = total_cover, color = Plot, group = Plot)) +
  geom_smooth(method = "lm", se = TRUE) +
  geom_point(
    position = position_jitter(w = 0.2, h = 0),
    size = 3,
    shape = "triangle"
  ) +
  theme_classic(base_size = 18) +
  theme(
    legend.text = element_markdown()
  ) +
  xlab("DBH (cm)") +
  ylab("CRAW Woody\nSimpson Index (D)") +
  theme(
    plot.margin = grid::unit(c(0, 0, 0, 0), "mm"),
    strip.text.x = element_text(face = "italic")
  ) +
  scale_color_manual(
    values = color_palette[1:3],
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*")
  ) +
  xlim(0, 20)

CRAW_simpson_woody_DBH_all_no_outliers <- ggplot(data = CRAW_data_primary_species_woody[-c(21,24, 31:41), ], aes(x = DBH_cm, y = total_cover, color = Plot)) +
  geom_smooth(method = "lm", se = TRUE, color = "black") +
  geom_point(
    position = position_jitter(w = 0.2, h = 0),
    size = 3,
    shape = "triangle"
  ) +
  theme_classic(base_size = 18) +
  theme(
    legend.text = element_markdown()
  ) +
  xlab("DBH (cm)") +
  ylab("CRAW Woody\nSimpson Index (D)") +
  theme(
    plot.margin = grid::unit(c(0, 0, 0, 0), "mm"),
    strip.text.x = element_text(face = "italic")
  ) +
  scale_color_manual(
    values = color_palette[1:3],
    name = "Plot Type",
    labels = c("*L. tulipifera*", "*P. occidentalis*", "*P. calleryana*")
  ) +
  xlim(0, 20)

# Remove two largest PYCA80 to get similar distribution of DBH across species
CRAW_model_simpson_woody_DBH_no_outliers <- lm(data = CRAW_data_primary_species_woody[-c(21,24),], simpson_index ~ Plot * DBH_cm)
plot(CRAW_model_simpson_woody_DBH_no_outliers) # checking the homogeneity of variances
qqnorm(residuals(CRAW_model_simpson_woody_DBH_no_outliers)) # checking the normality of the residuals
summary(CRAW_model_simpson_woody_DBH_no_outliers) # provides the F, df, and P value for the whole model (check the last line of the output)
anova(CRAW_model_simpson_woody_DBH_no_outliers) # provides the F, df, and P value for each independent factor
anova_stats(CRAW_model_simpson_woody_DBH_no_outliers) # provides the effect size (we are reporting Omega squared)
TukeyHSD(aov(data = CRAW_data_primary_species_woody[-c(21,24),], simpson_index ~ Plot * DBH_cm))
posthoc_Trends_Pairwise(CRAW_model_simpson_woody_DBH_no_outliers, "Plot", "DBH_cm", P_Adj = "bonferroni")

# Combine graphs
plot_analysis_wDBH_CRAWnative <- ggarrange(CRAW_richness_native_plot, CRAW_shannon_native_plot,
  ncol = 2, nrow = 1,
  hjust = -0.5, vjust = 1.5,
  legend = "bottom",
  common.legend = TRUE,
  labels = "AUTO"
)

ggsave(
  "plot_analysis_wDBH_CRAWnative.png",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output",
  plot = plot_analysis_wDBH_CRAWnative,
  width = 12,
  height = 5,
  dpi = 300
)

ggsave(
  "NebhutDukes2023_FigS9",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/ReviewerResponseSubmission/EPS",
  plot = plot_analysis_wDBH_CRAWnative,
  width = 12,
  height = 5,
  device = cairo_ps
)

plot_analysis_wDBH_CRAWwoody <- ggarrange(CRAW_simpson_woody_DBH_all, CRAW_simpson_woody_DBH_all_no_outliers,
                                           ncol = 2, nrow = 1,
                                           hjust = -0.5, vjust = 1.5,
                                           legend = "bottom",
                                           common.legend = TRUE,
                                           labels = "AUTO"
)

ggsave(
  "plot_analysis_wDBH_CRAWwoody.png",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output",
  plot = plot_analysis_wDBH_CRAWwoody,
  width = 8,
  height = 3.5,
  dpi = 300
)

ggsave(
  "NebhutDukes2023_FigS7",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/ReviewerResponseSubmission/EPS",
  plot = plot_analysis_wDBH_CRAWwoody,
  width = 8,
  height = 3.5,
  device = cairo_ps
)

ggsave(
  "SRNP_totalcov_woody_DBH.png",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/Final Analysis/Figure Output",
  plot = SRNP_totalcov_woody_DBH,
  width = 6,
  height = 3.5,
  dpi = 300
)

ggsave(
  "NebhutDukes2023_FigS8",
  path = "C:/Users/Andrea/OneDrive/Purdue/Research/Callery Pear/ReviewerResponseSubmission/EPS",
  plot = SRNP_totalcov_woody_DBH,
  width = 6,
  height = 3.5,
  device = cairo_ps
)